static const uint8_t unicode_rangetab[][2]={
	{0x0000 & 0xFF, 0x0009 & 0xFF},
	{0x000a & 0xFF, 0x000a & 0xFF},
	{0x000b & 0xFF, 0x000c & 0xFF},
	{0x000d & 0xFF, 0x000d & 0xFF},
	{0x000e & 0xFF, 0x001f & 0xFF},
	{0x007f & 0xFF, 0x009f & 0xFF},
	{0x00ad & 0xFF, 0x00ad & 0xFF},
	{0x0300 & 0xFF, 0x036f & 0xFF},
	{0x0483 & 0xFF, 0x0489 & 0xFF},
	{0x0591 & 0xFF, 0x05bd & 0xFF},
	{0x05bf & 0xFF, 0x05bf & 0xFF},
	{0x05c1 & 0xFF, 0x05c2 & 0xFF},
	{0x05c4 & 0xFF, 0x05c5 & 0xFF},
	{0x05c7 & 0xFF, 0x05c7 & 0xFF},
	{0x0600 & 0xFF, 0x0605 & 0xFF},
	{0x0610 & 0xFF, 0x061a & 0xFF},
	{0x061c & 0xFF, 0x061c & 0xFF},
	{0x064b & 0xFF, 0x065f & 0xFF},
	{0x0670 & 0xFF, 0x0670 & 0xFF},
	{0x06d6 & 0xFF, 0x06dc & 0xFF},
	{0x06dd & 0xFF, 0x06dd & 0xFF},
	{0x06df & 0xFF, 0x06e4 & 0xFF},
	{0x06e7 & 0xFF, 0x06e8 & 0xFF},
	{0x06ea & 0xFF, 0x06ed & 0xFF},
	{0x070f & 0xFF, 0x070f & 0xFF},
	{0x0711 & 0xFF, 0x0711 & 0xFF},
	{0x0730 & 0xFF, 0x074a & 0xFF},
	{0x07a6 & 0xFF, 0x07b0 & 0xFF},
	{0x07eb & 0xFF, 0x07f3 & 0xFF},
	{0x07fd & 0xFF, 0x07fd & 0xFF},
	{0x0816 & 0xFF, 0x0819 & 0xFF},
	{0x081b & 0xFF, 0x0823 & 0xFF},
	{0x0825 & 0xFF, 0x0827 & 0xFF},
	{0x0829 & 0xFF, 0x082d & 0xFF},
	{0x0859 & 0xFF, 0x085b & 0xFF},
	{0x0890 & 0xFF, 0x0891 & 0xFF},
	{0x0898 & 0xFF, 0x089f & 0xFF},
	{0x08ca & 0xFF, 0x08e1 & 0xFF},
	{0x08e2 & 0xFF, 0x08e2 & 0xFF},
	{0x08e3 & 0xFF, 0x08ff & 0xFF},
	{0x0900 & 0xFF, 0x0902 & 0xFF},
	{0x0903 & 0xFF, 0x0903 & 0xFF},
	{0x093a & 0xFF, 0x093a & 0xFF},
	{0x093b & 0xFF, 0x093b & 0xFF},
	{0x093c & 0xFF, 0x093c & 0xFF},
	{0x093e & 0xFF, 0x0940 & 0xFF},
	{0x0941 & 0xFF, 0x0948 & 0xFF},
	{0x0949 & 0xFF, 0x094c & 0xFF},
	{0x094d & 0xFF, 0x094d & 0xFF},
	{0x094e & 0xFF, 0x094f & 0xFF},
	{0x0951 & 0xFF, 0x0957 & 0xFF},
	{0x0962 & 0xFF, 0x0963 & 0xFF},
	{0x0981 & 0xFF, 0x0981 & 0xFF},
	{0x0982 & 0xFF, 0x0983 & 0xFF},
	{0x09bc & 0xFF, 0x09bc & 0xFF},
	{0x09be & 0xFF, 0x09be & 0xFF},
	{0x09bf & 0xFF, 0x09c0 & 0xFF},
	{0x09c1 & 0xFF, 0x09c4 & 0xFF},
	{0x09c7 & 0xFF, 0x09c8 & 0xFF},
	{0x09cb & 0xFF, 0x09cc & 0xFF},
	{0x09cd & 0xFF, 0x09cd & 0xFF},
	{0x09d7 & 0xFF, 0x09d7 & 0xFF},
	{0x09e2 & 0xFF, 0x09e3 & 0xFF},
	{0x09fe & 0xFF, 0x09fe & 0xFF},
	{0x0a01 & 0xFF, 0x0a02 & 0xFF},
	{0x0a03 & 0xFF, 0x0a03 & 0xFF},
	{0x0a3c & 0xFF, 0x0a3c & 0xFF},
	{0x0a3e & 0xFF, 0x0a40 & 0xFF},
	{0x0a41 & 0xFF, 0x0a42 & 0xFF},
	{0x0a47 & 0xFF, 0x0a48 & 0xFF},
	{0x0a4b & 0xFF, 0x0a4d & 0xFF},
	{0x0a51 & 0xFF, 0x0a51 & 0xFF},
	{0x0a70 & 0xFF, 0x0a71 & 0xFF},
	{0x0a75 & 0xFF, 0x0a75 & 0xFF},
	{0x0a81 & 0xFF, 0x0a82 & 0xFF},
	{0x0a83 & 0xFF, 0x0a83 & 0xFF},
	{0x0abc & 0xFF, 0x0abc & 0xFF},
	{0x0abe & 0xFF, 0x0ac0 & 0xFF},
	{0x0ac1 & 0xFF, 0x0ac5 & 0xFF},
	{0x0ac7 & 0xFF, 0x0ac8 & 0xFF},
	{0x0ac9 & 0xFF, 0x0ac9 & 0xFF},
	{0x0acb & 0xFF, 0x0acc & 0xFF},
	{0x0acd & 0xFF, 0x0acd & 0xFF},
	{0x0ae2 & 0xFF, 0x0ae3 & 0xFF},
	{0x0afa & 0xFF, 0x0aff & 0xFF},
	{0x0b01 & 0xFF, 0x0b01 & 0xFF},
	{0x0b02 & 0xFF, 0x0b03 & 0xFF},
	{0x0b3c & 0xFF, 0x0b3c & 0xFF},
	{0x0b3e & 0xFF, 0x0b3f & 0xFF},
	{0x0b40 & 0xFF, 0x0b40 & 0xFF},
	{0x0b41 & 0xFF, 0x0b44 & 0xFF},
	{0x0b47 & 0xFF, 0x0b48 & 0xFF},
	{0x0b4b & 0xFF, 0x0b4c & 0xFF},
	{0x0b4d & 0xFF, 0x0b4d & 0xFF},
	{0x0b55 & 0xFF, 0x0b57 & 0xFF},
	{0x0b62 & 0xFF, 0x0b63 & 0xFF},
	{0x0b82 & 0xFF, 0x0b82 & 0xFF},
	{0x0bbe & 0xFF, 0x0bbe & 0xFF},
	{0x0bbf & 0xFF, 0x0bbf & 0xFF},
	{0x0bc0 & 0xFF, 0x0bc0 & 0xFF},
	{0x0bc1 & 0xFF, 0x0bc2 & 0xFF},
	{0x0bc6 & 0xFF, 0x0bc8 & 0xFF},
	{0x0bca & 0xFF, 0x0bcc & 0xFF},
	{0x0bcd & 0xFF, 0x0bcd & 0xFF},
	{0x0bd7 & 0xFF, 0x0bd7 & 0xFF},
	{0x0c00 & 0xFF, 0x0c00 & 0xFF},
	{0x0c01 & 0xFF, 0x0c03 & 0xFF},
	{0x0c04 & 0xFF, 0x0c04 & 0xFF},
	{0x0c3c & 0xFF, 0x0c3c & 0xFF},
	{0x0c3e & 0xFF, 0x0c40 & 0xFF},
	{0x0c41 & 0xFF, 0x0c44 & 0xFF},
	{0x0c46 & 0xFF, 0x0c48 & 0xFF},
	{0x0c4a & 0xFF, 0x0c4d & 0xFF},
	{0x0c55 & 0xFF, 0x0c56 & 0xFF},
	{0x0c62 & 0xFF, 0x0c63 & 0xFF},
	{0x0c81 & 0xFF, 0x0c81 & 0xFF},
	{0x0c82 & 0xFF, 0x0c83 & 0xFF},
	{0x0cbc & 0xFF, 0x0cbc & 0xFF},
	{0x0cbe & 0xFF, 0x0cbe & 0xFF},
	{0x0cbf & 0xFF, 0x0cbf & 0xFF},
	{0x0cc0 & 0xFF, 0x0cc1 & 0xFF},
	{0x0cc2 & 0xFF, 0x0cc2 & 0xFF},
	{0x0cc3 & 0xFF, 0x0cc4 & 0xFF},
	{0x0cc6 & 0xFF, 0x0cc6 & 0xFF},
	{0x0cc7 & 0xFF, 0x0cc8 & 0xFF},
	{0x0cca & 0xFF, 0x0ccb & 0xFF},
	{0x0ccc & 0xFF, 0x0ccd & 0xFF},
	{0x0cd5 & 0xFF, 0x0cd6 & 0xFF},
	{0x0ce2 & 0xFF, 0x0ce3 & 0xFF},
	{0x0cf3 & 0xFF, 0x0cf3 & 0xFF},
	{0x0d00 & 0xFF, 0x0d01 & 0xFF},
	{0x0d02 & 0xFF, 0x0d03 & 0xFF},
	{0x0d3b & 0xFF, 0x0d3c & 0xFF},
	{0x0d3e & 0xFF, 0x0d3e & 0xFF},
	{0x0d3f & 0xFF, 0x0d40 & 0xFF},
	{0x0d41 & 0xFF, 0x0d44 & 0xFF},
	{0x0d46 & 0xFF, 0x0d48 & 0xFF},
	{0x0d4a & 0xFF, 0x0d4c & 0xFF},
	{0x0d4d & 0xFF, 0x0d4d & 0xFF},
	{0x0d4e & 0xFF, 0x0d4e & 0xFF},
	{0x0d57 & 0xFF, 0x0d57 & 0xFF},
	{0x0d62 & 0xFF, 0x0d63 & 0xFF},
	{0x0d81 & 0xFF, 0x0d81 & 0xFF},
	{0x0d82 & 0xFF, 0x0d83 & 0xFF},
	{0x0dca & 0xFF, 0x0dca & 0xFF},
	{0x0dcf & 0xFF, 0x0dcf & 0xFF},
	{0x0dd0 & 0xFF, 0x0dd1 & 0xFF},
	{0x0dd2 & 0xFF, 0x0dd4 & 0xFF},
	{0x0dd6 & 0xFF, 0x0dd6 & 0xFF},
	{0x0dd8 & 0xFF, 0x0dde & 0xFF},
	{0x0ddf & 0xFF, 0x0ddf & 0xFF},
	{0x0df2 & 0xFF, 0x0df3 & 0xFF},
	{0x0e31 & 0xFF, 0x0e31 & 0xFF},
	{0x0e33 & 0xFF, 0x0e33 & 0xFF},
	{0x0e34 & 0xFF, 0x0e3a & 0xFF},
	{0x0e47 & 0xFF, 0x0e4e & 0xFF},
	{0x0eb1 & 0xFF, 0x0eb1 & 0xFF},
	{0x0eb3 & 0xFF, 0x0eb3 & 0xFF},
	{0x0eb4 & 0xFF, 0x0ebc & 0xFF},
	{0x0ec8 & 0xFF, 0x0ece & 0xFF},
	{0x0f18 & 0xFF, 0x0f19 & 0xFF},
	{0x0f35 & 0xFF, 0x0f35 & 0xFF},
	{0x0f37 & 0xFF, 0x0f37 & 0xFF},
	{0x0f39 & 0xFF, 0x0f39 & 0xFF},
	{0x0f3e & 0xFF, 0x0f3f & 0xFF},
	{0x0f71 & 0xFF, 0x0f7e & 0xFF},
	{0x0f7f & 0xFF, 0x0f7f & 0xFF},
	{0x0f80 & 0xFF, 0x0f84 & 0xFF},
	{0x0f86 & 0xFF, 0x0f87 & 0xFF},
	{0x0f8d & 0xFF, 0x0f97 & 0xFF},
	{0x0f99 & 0xFF, 0x0fbc & 0xFF},
	{0x0fc6 & 0xFF, 0x0fc6 & 0xFF},
	{0x102d & 0xFF, 0x1030 & 0xFF},
	{0x1031 & 0xFF, 0x1031 & 0xFF},
	{0x1032 & 0xFF, 0x1037 & 0xFF},
	{0x1039 & 0xFF, 0x103a & 0xFF},
	{0x103b & 0xFF, 0x103c & 0xFF},
	{0x103d & 0xFF, 0x103e & 0xFF},
	{0x1056 & 0xFF, 0x1057 & 0xFF},
	{0x1058 & 0xFF, 0x1059 & 0xFF},
	{0x105e & 0xFF, 0x1060 & 0xFF},
	{0x1071 & 0xFF, 0x1074 & 0xFF},
	{0x1082 & 0xFF, 0x1082 & 0xFF},
	{0x1084 & 0xFF, 0x1084 & 0xFF},
	{0x1085 & 0xFF, 0x1086 & 0xFF},
	{0x108d & 0xFF, 0x108d & 0xFF},
	{0x109d & 0xFF, 0x109d & 0xFF},
	{0x1100 & 0xFF, 0x115f & 0xFF},
	{0x1160 & 0xFF, 0x11a7 & 0xFF},
	{0x11a8 & 0xFF, 0x11ff & 0xFF},
	{0x135d & 0xFF, 0x135f & 0xFF},
	{0x1712 & 0xFF, 0x1714 & 0xFF},
	{0x1715 & 0xFF, 0x1715 & 0xFF},
	{0x1732 & 0xFF, 0x1733 & 0xFF},
	{0x1734 & 0xFF, 0x1734 & 0xFF},
	{0x1752 & 0xFF, 0x1753 & 0xFF},
	{0x1772 & 0xFF, 0x1773 & 0xFF},
	{0x17b4 & 0xFF, 0x17b5 & 0xFF},
	{0x17b6 & 0xFF, 0x17b6 & 0xFF},
	{0x17b7 & 0xFF, 0x17bd & 0xFF},
	{0x17be & 0xFF, 0x17c5 & 0xFF},
	{0x17c6 & 0xFF, 0x17c6 & 0xFF},
	{0x17c7 & 0xFF, 0x17c8 & 0xFF},
	{0x17c9 & 0xFF, 0x17d3 & 0xFF},
	{0x17dd & 0xFF, 0x17dd & 0xFF},
	{0x180b & 0xFF, 0x180d & 0xFF},
	{0x180e & 0xFF, 0x180e & 0xFF},
	{0x180f & 0xFF, 0x180f & 0xFF},
	{0x1885 & 0xFF, 0x1886 & 0xFF},
	{0x18a9 & 0xFF, 0x18a9 & 0xFF},
	{0x1920 & 0xFF, 0x1922 & 0xFF},
	{0x1923 & 0xFF, 0x1926 & 0xFF},
	{0x1927 & 0xFF, 0x1928 & 0xFF},
	{0x1929 & 0xFF, 0x192b & 0xFF},
	{0x1930 & 0xFF, 0x1931 & 0xFF},
	{0x1932 & 0xFF, 0x1932 & 0xFF},
	{0x1933 & 0xFF, 0x1938 & 0xFF},
	{0x1939 & 0xFF, 0x193b & 0xFF},
	{0x1a17 & 0xFF, 0x1a18 & 0xFF},
	{0x1a19 & 0xFF, 0x1a1a & 0xFF},
	{0x1a1b & 0xFF, 0x1a1b & 0xFF},
	{0x1a55 & 0xFF, 0x1a55 & 0xFF},
	{0x1a56 & 0xFF, 0x1a56 & 0xFF},
	{0x1a57 & 0xFF, 0x1a57 & 0xFF},
	{0x1a58 & 0xFF, 0x1a5e & 0xFF},
	{0x1a60 & 0xFF, 0x1a60 & 0xFF},
	{0x1a62 & 0xFF, 0x1a62 & 0xFF},
	{0x1a65 & 0xFF, 0x1a6c & 0xFF},
	{0x1a6d & 0xFF, 0x1a72 & 0xFF},
	{0x1a73 & 0xFF, 0x1a7c & 0xFF},
	{0x1a7f & 0xFF, 0x1a7f & 0xFF},
	{0x1ab0 & 0xFF, 0x1ace & 0xFF},
	{0x1b00 & 0xFF, 0x1b03 & 0xFF},
	{0x1b04 & 0xFF, 0x1b04 & 0xFF},
	{0x1b34 & 0xFF, 0x1b3a & 0xFF},
	{0x1b3b & 0xFF, 0x1b3b & 0xFF},
	{0x1b3c & 0xFF, 0x1b3c & 0xFF},
	{0x1b3d & 0xFF, 0x1b41 & 0xFF},
	{0x1b42 & 0xFF, 0x1b42 & 0xFF},
	{0x1b43 & 0xFF, 0x1b44 & 0xFF},
	{0x1b6b & 0xFF, 0x1b73 & 0xFF},
	{0x1b80 & 0xFF, 0x1b81 & 0xFF},
	{0x1b82 & 0xFF, 0x1b82 & 0xFF},
	{0x1ba1 & 0xFF, 0x1ba1 & 0xFF},
	{0x1ba2 & 0xFF, 0x1ba5 & 0xFF},
	{0x1ba6 & 0xFF, 0x1ba7 & 0xFF},
	{0x1ba8 & 0xFF, 0x1ba9 & 0xFF},
	{0x1baa & 0xFF, 0x1baa & 0xFF},
	{0x1bab & 0xFF, 0x1bad & 0xFF},
	{0x1be6 & 0xFF, 0x1be6 & 0xFF},
	{0x1be7 & 0xFF, 0x1be7 & 0xFF},
	{0x1be8 & 0xFF, 0x1be9 & 0xFF},
	{0x1bea & 0xFF, 0x1bec & 0xFF},
	{0x1bed & 0xFF, 0x1bed & 0xFF},
	{0x1bee & 0xFF, 0x1bee & 0xFF},
	{0x1bef & 0xFF, 0x1bf1 & 0xFF},
	{0x1bf2 & 0xFF, 0x1bf3 & 0xFF},
	{0x1c24 & 0xFF, 0x1c2b & 0xFF},
	{0x1c2c & 0xFF, 0x1c33 & 0xFF},
	{0x1c34 & 0xFF, 0x1c35 & 0xFF},
	{0x1c36 & 0xFF, 0x1c37 & 0xFF},
	{0x1cd0 & 0xFF, 0x1cd2 & 0xFF},
	{0x1cd4 & 0xFF, 0x1ce0 & 0xFF},
	{0x1ce1 & 0xFF, 0x1ce1 & 0xFF},
	{0x1ce2 & 0xFF, 0x1ce8 & 0xFF},
	{0x1ced & 0xFF, 0x1ced & 0xFF},
	{0x1cf4 & 0xFF, 0x1cf4 & 0xFF},
	{0x1cf7 & 0xFF, 0x1cf7 & 0xFF},
	{0x1cf8 & 0xFF, 0x1cf9 & 0xFF},
	{0x1dc0 & 0xFF, 0x1dff & 0xFF},
	{0x200b & 0xFF, 0x200b & 0xFF},
	{0x200c & 0xFF, 0x200c & 0xFF},
	{0x200d & 0xFF, 0x200d & 0xFF},
	{0x200e & 0xFF, 0x200f & 0xFF},
	{0x2028 & 0xFF, 0x202e & 0xFF},
	{0x2060 & 0xFF, 0x206f & 0xFF},
	{0x20d0 & 0xFF, 0x20f0 & 0xFF},
	{0x2cef & 0xFF, 0x2cf1 & 0xFF},
	{0x2d7f & 0xFF, 0x2d7f & 0xFF},
	{0x2de0 & 0xFF, 0x2dff & 0xFF},
	{0x302a & 0xFF, 0x302f & 0xFF},
	{0x3099 & 0xFF, 0x309a & 0xFF},
	{0xa66f & 0xFF, 0xa672 & 0xFF},
	{0xa674 & 0xFF, 0xa67d & 0xFF},
	{0xa69e & 0xFF, 0xa69f & 0xFF},
	{0xa6f0 & 0xFF, 0xa6f1 & 0xFF},
	{0xa802 & 0xFF, 0xa802 & 0xFF},
	{0xa806 & 0xFF, 0xa806 & 0xFF},
	{0xa80b & 0xFF, 0xa80b & 0xFF},
	{0xa823 & 0xFF, 0xa824 & 0xFF},
	{0xa825 & 0xFF, 0xa826 & 0xFF},
	{0xa827 & 0xFF, 0xa827 & 0xFF},
	{0xa82c & 0xFF, 0xa82c & 0xFF},
	{0xa880 & 0xFF, 0xa881 & 0xFF},
	{0xa8b4 & 0xFF, 0xa8c3 & 0xFF},
	{0xa8c4 & 0xFF, 0xa8c5 & 0xFF},
	{0xa8e0 & 0xFF, 0xa8f1 & 0xFF},
	{0xa8ff & 0xFF, 0xa8ff & 0xFF},
	{0xa926 & 0xFF, 0xa92d & 0xFF},
	{0xa947 & 0xFF, 0xa951 & 0xFF},
	{0xa952 & 0xFF, 0xa953 & 0xFF},
	{0xa960 & 0xFF, 0xa97c & 0xFF},
	{0xa980 & 0xFF, 0xa982 & 0xFF},
	{0xa983 & 0xFF, 0xa983 & 0xFF},
	{0xa9b3 & 0xFF, 0xa9b3 & 0xFF},
	{0xa9b4 & 0xFF, 0xa9b5 & 0xFF},
	{0xa9b6 & 0xFF, 0xa9b9 & 0xFF},
	{0xa9ba & 0xFF, 0xa9bb & 0xFF},
	{0xa9bc & 0xFF, 0xa9bd & 0xFF},
	{0xa9be & 0xFF, 0xa9c0 & 0xFF},
	{0xa9e5 & 0xFF, 0xa9e5 & 0xFF},
	{0xaa29 & 0xFF, 0xaa2e & 0xFF},
	{0xaa2f & 0xFF, 0xaa30 & 0xFF},
	{0xaa31 & 0xFF, 0xaa32 & 0xFF},
	{0xaa33 & 0xFF, 0xaa34 & 0xFF},
	{0xaa35 & 0xFF, 0xaa36 & 0xFF},
	{0xaa43 & 0xFF, 0xaa43 & 0xFF},
	{0xaa4c & 0xFF, 0xaa4c & 0xFF},
	{0xaa4d & 0xFF, 0xaa4d & 0xFF},
	{0xaa7c & 0xFF, 0xaa7c & 0xFF},
	{0xaab0 & 0xFF, 0xaab0 & 0xFF},
	{0xaab2 & 0xFF, 0xaab4 & 0xFF},
	{0xaab7 & 0xFF, 0xaab8 & 0xFF},
	{0xaabe & 0xFF, 0xaabf & 0xFF},
	{0xaac1 & 0xFF, 0xaac1 & 0xFF},
	{0xaaeb & 0xFF, 0xaaeb & 0xFF},
	{0xaaec & 0xFF, 0xaaed & 0xFF},
	{0xaaee & 0xFF, 0xaaef & 0xFF},
	{0xaaf5 & 0xFF, 0xaaf5 & 0xFF},
	{0xaaf6 & 0xFF, 0xaaf6 & 0xFF},
	{0xabe3 & 0xFF, 0xabe4 & 0xFF},
	{0xabe5 & 0xFF, 0xabe5 & 0xFF},
	{0xabe6 & 0xFF, 0xabe7 & 0xFF},
	{0xabe8 & 0xFF, 0xabe8 & 0xFF},
	{0xabe9 & 0xFF, 0xabea & 0xFF},
	{0xabec & 0xFF, 0xabec & 0xFF},
	{0xabed & 0xFF, 0xabed & 0xFF},
	{0xac00 & 0xFF, 0xac00 & 0xFF},
	{0xac01 & 0xFF, 0xac1b & 0xFF},
	{0xac1c & 0xFF, 0xac1c & 0xFF},
	{0xac1d & 0xFF, 0xac37 & 0xFF},
	{0xac38 & 0xFF, 0xac38 & 0xFF},
	{0xac39 & 0xFF, 0xac53 & 0xFF},
	{0xac54 & 0xFF, 0xac54 & 0xFF},
	{0xac55 & 0xFF, 0xac6f & 0xFF},
	{0xac70 & 0xFF, 0xac70 & 0xFF},
	{0xac71 & 0xFF, 0xac8b & 0xFF},
	{0xac8c & 0xFF, 0xac8c & 0xFF},
	{0xac8d & 0xFF, 0xaca7 & 0xFF},
	{0xaca8 & 0xFF, 0xaca8 & 0xFF},
	{0xaca9 & 0xFF, 0xacc3 & 0xFF},
	{0xacc4 & 0xFF, 0xacc4 & 0xFF},
	{0xacc5 & 0xFF, 0xacdf & 0xFF},
	{0xace0 & 0xFF, 0xace0 & 0xFF},
	{0xace1 & 0xFF, 0xacfb & 0xFF},
	{0xacfc & 0xFF, 0xacfc & 0xFF},
	{0xacfd & 0xFF, 0xacff & 0xFF},
	{0xad00 & 0xFF, 0xad17 & 0xFF},
	{0xad18 & 0xFF, 0xad18 & 0xFF},
	{0xad19 & 0xFF, 0xad33 & 0xFF},
	{0xad34 & 0xFF, 0xad34 & 0xFF},
	{0xad35 & 0xFF, 0xad4f & 0xFF},
	{0xad50 & 0xFF, 0xad50 & 0xFF},
	{0xad51 & 0xFF, 0xad6b & 0xFF},
	{0xad6c & 0xFF, 0xad6c & 0xFF},
	{0xad6d & 0xFF, 0xad87 & 0xFF},
	{0xad88 & 0xFF, 0xad88 & 0xFF},
	{0xad89 & 0xFF, 0xada3 & 0xFF},
	{0xada4 & 0xFF, 0xada4 & 0xFF},
	{0xada5 & 0xFF, 0xadbf & 0xFF},
	{0xadc0 & 0xFF, 0xadc0 & 0xFF},
	{0xadc1 & 0xFF, 0xaddb & 0xFF},
	{0xaddc & 0xFF, 0xaddc & 0xFF},
	{0xaddd & 0xFF, 0xadf7 & 0xFF},
	{0xadf8 & 0xFF, 0xadf8 & 0xFF},
	{0xadf9 & 0xFF, 0xadff & 0xFF},
	{0xae00 & 0xFF, 0xae13 & 0xFF},
	{0xae14 & 0xFF, 0xae14 & 0xFF},
	{0xae15 & 0xFF, 0xae2f & 0xFF},
	{0xae30 & 0xFF, 0xae30 & 0xFF},
	{0xae31 & 0xFF, 0xae4b & 0xFF},
	{0xae4c & 0xFF, 0xae4c & 0xFF},
	{0xae4d & 0xFF, 0xae67 & 0xFF},
	{0xae68 & 0xFF, 0xae68 & 0xFF},
	{0xae69 & 0xFF, 0xae83 & 0xFF},
	{0xae84 & 0xFF, 0xae84 & 0xFF},
	{0xae85 & 0xFF, 0xae9f & 0xFF},
	{0xaea0 & 0xFF, 0xaea0 & 0xFF},
	{0xaea1 & 0xFF, 0xaebb & 0xFF},
	{0xaebc & 0xFF, 0xaebc & 0xFF},
	{0xaebd & 0xFF, 0xaed7 & 0xFF},
	{0xaed8 & 0xFF, 0xaed8 & 0xFF},
	{0xaed9 & 0xFF, 0xaef3 & 0xFF},
	{0xaef4 & 0xFF, 0xaef4 & 0xFF},
	{0xaef5 & 0xFF, 0xaeff & 0xFF},
	{0xaf00 & 0xFF, 0xaf0f & 0xFF},
	{0xaf10 & 0xFF, 0xaf10 & 0xFF},
	{0xaf11 & 0xFF, 0xaf2b & 0xFF},
	{0xaf2c & 0xFF, 0xaf2c & 0xFF},
	{0xaf2d & 0xFF, 0xaf47 & 0xFF},
	{0xaf48 & 0xFF, 0xaf48 & 0xFF},
	{0xaf49 & 0xFF, 0xaf63 & 0xFF},
	{0xaf64 & 0xFF, 0xaf64 & 0xFF},
	{0xaf65 & 0xFF, 0xaf7f & 0xFF},
	{0xaf80 & 0xFF, 0xaf80 & 0xFF},
	{0xaf81 & 0xFF, 0xaf9b & 0xFF},
	{0xaf9c & 0xFF, 0xaf9c & 0xFF},
	{0xaf9d & 0xFF, 0xafb7 & 0xFF},
	{0xafb8 & 0xFF, 0xafb8 & 0xFF},
	{0xafb9 & 0xFF, 0xafd3 & 0xFF},
	{0xafd4 & 0xFF, 0xafd4 & 0xFF},
	{0xafd5 & 0xFF, 0xafef & 0xFF},
	{0xaff0 & 0xFF, 0xaff0 & 0xFF},
	{0xaff1 & 0xFF, 0xafff & 0xFF},
	{0xb000 & 0xFF, 0xb00b & 0xFF},
	{0xb00c & 0xFF, 0xb00c & 0xFF},
	{0xb00d & 0xFF, 0xb027 & 0xFF},
	{0xb028 & 0xFF, 0xb028 & 0xFF},
	{0xb029 & 0xFF, 0xb043 & 0xFF},
	{0xb044 & 0xFF, 0xb044 & 0xFF},
	{0xb045 & 0xFF, 0xb05f & 0xFF},
	{0xb060 & 0xFF, 0xb060 & 0xFF},
	{0xb061 & 0xFF, 0xb07b & 0xFF},
	{0xb07c & 0xFF, 0xb07c & 0xFF},
	{0xb07d & 0xFF, 0xb097 & 0xFF},
	{0xb098 & 0xFF, 0xb098 & 0xFF},
	{0xb099 & 0xFF, 0xb0b3 & 0xFF},
	{0xb0b4 & 0xFF, 0xb0b4 & 0xFF},
	{0xb0b5 & 0xFF, 0xb0cf & 0xFF},
	{0xb0d0 & 0xFF, 0xb0d0 & 0xFF},
	{0xb0d1 & 0xFF, 0xb0eb & 0xFF},
	{0xb0ec & 0xFF, 0xb0ec & 0xFF},
	{0xb0ed & 0xFF, 0xb0ff & 0xFF},
	{0xb100 & 0xFF, 0xb107 & 0xFF},
	{0xb108 & 0xFF, 0xb108 & 0xFF},
	{0xb109 & 0xFF, 0xb123 & 0xFF},
	{0xb124 & 0xFF, 0xb124 & 0xFF},
	{0xb125 & 0xFF, 0xb13f & 0xFF},
	{0xb140 & 0xFF, 0xb140 & 0xFF},
	{0xb141 & 0xFF, 0xb15b & 0xFF},
	{0xb15c & 0xFF, 0xb15c & 0xFF},
	{0xb15d & 0xFF, 0xb177 & 0xFF},
	{0xb178 & 0xFF, 0xb178 & 0xFF},
	{0xb179 & 0xFF, 0xb193 & 0xFF},
	{0xb194 & 0xFF, 0xb194 & 0xFF},
	{0xb195 & 0xFF, 0xb1af & 0xFF},
	{0xb1b0 & 0xFF, 0xb1b0 & 0xFF},
	{0xb1b1 & 0xFF, 0xb1cb & 0xFF},
	{0xb1cc & 0xFF, 0xb1cc & 0xFF},
	{0xb1cd & 0xFF, 0xb1e7 & 0xFF},
	{0xb1e8 & 0xFF, 0xb1e8 & 0xFF},
	{0xb1e9 & 0xFF, 0xb1ff & 0xFF},
	{0xb200 & 0xFF, 0xb203 & 0xFF},
	{0xb204 & 0xFF, 0xb204 & 0xFF},
	{0xb205 & 0xFF, 0xb21f & 0xFF},
	{0xb220 & 0xFF, 0xb220 & 0xFF},
	{0xb221 & 0xFF, 0xb23b & 0xFF},
	{0xb23c & 0xFF, 0xb23c & 0xFF},
	{0xb23d & 0xFF, 0xb257 & 0xFF},
	{0xb258 & 0xFF, 0xb258 & 0xFF},
	{0xb259 & 0xFF, 0xb273 & 0xFF},
	{0xb274 & 0xFF, 0xb274 & 0xFF},
	{0xb275 & 0xFF, 0xb28f & 0xFF},
	{0xb290 & 0xFF, 0xb290 & 0xFF},
	{0xb291 & 0xFF, 0xb2ab & 0xFF},
	{0xb2ac & 0xFF, 0xb2ac & 0xFF},
	{0xb2ad & 0xFF, 0xb2c7 & 0xFF},
	{0xb2c8 & 0xFF, 0xb2c8 & 0xFF},
	{0xb2c9 & 0xFF, 0xb2e3 & 0xFF},
	{0xb2e4 & 0xFF, 0xb2e4 & 0xFF},
	{0xb2e5 & 0xFF, 0xb2ff & 0xFF},
	{0xb300 & 0xFF, 0xb300 & 0xFF},
	{0xb301 & 0xFF, 0xb31b & 0xFF},
	{0xb31c & 0xFF, 0xb31c & 0xFF},
	{0xb31d & 0xFF, 0xb337 & 0xFF},
	{0xb338 & 0xFF, 0xb338 & 0xFF},
	{0xb339 & 0xFF, 0xb353 & 0xFF},
	{0xb354 & 0xFF, 0xb354 & 0xFF},
	{0xb355 & 0xFF, 0xb36f & 0xFF},
	{0xb370 & 0xFF, 0xb370 & 0xFF},
	{0xb371 & 0xFF, 0xb38b & 0xFF},
	{0xb38c & 0xFF, 0xb38c & 0xFF},
	{0xb38d & 0xFF, 0xb3a7 & 0xFF},
	{0xb3a8 & 0xFF, 0xb3a8 & 0xFF},
	{0xb3a9 & 0xFF, 0xb3c3 & 0xFF},
	{0xb3c4 & 0xFF, 0xb3c4 & 0xFF},
	{0xb3c5 & 0xFF, 0xb3df & 0xFF},
	{0xb3e0 & 0xFF, 0xb3e0 & 0xFF},
	{0xb3e1 & 0xFF, 0xb3fb & 0xFF},
	{0xb3fc & 0xFF, 0xb3fc & 0xFF},
	{0xb3fd & 0xFF, 0xb3ff & 0xFF},
	{0xb400 & 0xFF, 0xb417 & 0xFF},
	{0xb418 & 0xFF, 0xb418 & 0xFF},
	{0xb419 & 0xFF, 0xb433 & 0xFF},
	{0xb434 & 0xFF, 0xb434 & 0xFF},
	{0xb435 & 0xFF, 0xb44f & 0xFF},
	{0xb450 & 0xFF, 0xb450 & 0xFF},
	{0xb451 & 0xFF, 0xb46b & 0xFF},
	{0xb46c & 0xFF, 0xb46c & 0xFF},
	{0xb46d & 0xFF, 0xb487 & 0xFF},
	{0xb488 & 0xFF, 0xb488 & 0xFF},
	{0xb489 & 0xFF, 0xb4a3 & 0xFF},
	{0xb4a4 & 0xFF, 0xb4a4 & 0xFF},
	{0xb4a5 & 0xFF, 0xb4bf & 0xFF},
	{0xb4c0 & 0xFF, 0xb4c0 & 0xFF},
	{0xb4c1 & 0xFF, 0xb4db & 0xFF},
	{0xb4dc & 0xFF, 0xb4dc & 0xFF},
	{0xb4dd & 0xFF, 0xb4f7 & 0xFF},
	{0xb4f8 & 0xFF, 0xb4f8 & 0xFF},
	{0xb4f9 & 0xFF, 0xb4ff & 0xFF},
	{0xb500 & 0xFF, 0xb513 & 0xFF},
	{0xb514 & 0xFF, 0xb514 & 0xFF},
	{0xb515 & 0xFF, 0xb52f & 0xFF},
	{0xb530 & 0xFF, 0xb530 & 0xFF},
	{0xb531 & 0xFF, 0xb54b & 0xFF},
	{0xb54c & 0xFF, 0xb54c & 0xFF},
	{0xb54d & 0xFF, 0xb567 & 0xFF},
	{0xb568 & 0xFF, 0xb568 & 0xFF},
	{0xb569 & 0xFF, 0xb583 & 0xFF},
	{0xb584 & 0xFF, 0xb584 & 0xFF},
	{0xb585 & 0xFF, 0xb59f & 0xFF},
	{0xb5a0 & 0xFF, 0xb5a0 & 0xFF},
	{0xb5a1 & 0xFF, 0xb5bb & 0xFF},
	{0xb5bc & 0xFF, 0xb5bc & 0xFF},
	{0xb5bd & 0xFF, 0xb5d7 & 0xFF},
	{0xb5d8 & 0xFF, 0xb5d8 & 0xFF},
	{0xb5d9 & 0xFF, 0xb5f3 & 0xFF},
	{0xb5f4 & 0xFF, 0xb5f4 & 0xFF},
	{0xb5f5 & 0xFF, 0xb5ff & 0xFF},
	{0xb600 & 0xFF, 0xb60f & 0xFF},
	{0xb610 & 0xFF, 0xb610 & 0xFF},
	{0xb611 & 0xFF, 0xb62b & 0xFF},
	{0xb62c & 0xFF, 0xb62c & 0xFF},
	{0xb62d & 0xFF, 0xb647 & 0xFF},
	{0xb648 & 0xFF, 0xb648 & 0xFF},
	{0xb649 & 0xFF, 0xb663 & 0xFF},
	{0xb664 & 0xFF, 0xb664 & 0xFF},
	{0xb665 & 0xFF, 0xb67f & 0xFF},
	{0xb680 & 0xFF, 0xb680 & 0xFF},
	{0xb681 & 0xFF, 0xb69b & 0xFF},
	{0xb69c & 0xFF, 0xb69c & 0xFF},
	{0xb69d & 0xFF, 0xb6b7 & 0xFF},
	{0xb6b8 & 0xFF, 0xb6b8 & 0xFF},
	{0xb6b9 & 0xFF, 0xb6d3 & 0xFF},
	{0xb6d4 & 0xFF, 0xb6d4 & 0xFF},
	{0xb6d5 & 0xFF, 0xb6ef & 0xFF},
	{0xb6f0 & 0xFF, 0xb6f0 & 0xFF},
	{0xb6f1 & 0xFF, 0xb6ff & 0xFF},
	{0xb700 & 0xFF, 0xb70b & 0xFF},
	{0xb70c & 0xFF, 0xb70c & 0xFF},
	{0xb70d & 0xFF, 0xb727 & 0xFF},
	{0xb728 & 0xFF, 0xb728 & 0xFF},
	{0xb729 & 0xFF, 0xb743 & 0xFF},
	{0xb744 & 0xFF, 0xb744 & 0xFF},
	{0xb745 & 0xFF, 0xb75f & 0xFF},
	{0xb760 & 0xFF, 0xb760 & 0xFF},
	{0xb761 & 0xFF, 0xb77b & 0xFF},
	{0xb77c & 0xFF, 0xb77c & 0xFF},
	{0xb77d & 0xFF, 0xb797 & 0xFF},
	{0xb798 & 0xFF, 0xb798 & 0xFF},
	{0xb799 & 0xFF, 0xb7b3 & 0xFF},
	{0xb7b4 & 0xFF, 0xb7b4 & 0xFF},
	{0xb7b5 & 0xFF, 0xb7cf & 0xFF},
	{0xb7d0 & 0xFF, 0xb7d0 & 0xFF},
	{0xb7d1 & 0xFF, 0xb7eb & 0xFF},
	{0xb7ec & 0xFF, 0xb7ec & 0xFF},
	{0xb7ed & 0xFF, 0xb7ff & 0xFF},
	{0xb800 & 0xFF, 0xb807 & 0xFF},
	{0xb808 & 0xFF, 0xb808 & 0xFF},
	{0xb809 & 0xFF, 0xb823 & 0xFF},
	{0xb824 & 0xFF, 0xb824 & 0xFF},
	{0xb825 & 0xFF, 0xb83f & 0xFF},
	{0xb840 & 0xFF, 0xb840 & 0xFF},
	{0xb841 & 0xFF, 0xb85b & 0xFF},
	{0xb85c & 0xFF, 0xb85c & 0xFF},
	{0xb85d & 0xFF, 0xb877 & 0xFF},
	{0xb878 & 0xFF, 0xb878 & 0xFF},
	{0xb879 & 0xFF, 0xb893 & 0xFF},
	{0xb894 & 0xFF, 0xb894 & 0xFF},
	{0xb895 & 0xFF, 0xb8af & 0xFF},
	{0xb8b0 & 0xFF, 0xb8b0 & 0xFF},
	{0xb8b1 & 0xFF, 0xb8cb & 0xFF},
	{0xb8cc & 0xFF, 0xb8cc & 0xFF},
	{0xb8cd & 0xFF, 0xb8e7 & 0xFF},
	{0xb8e8 & 0xFF, 0xb8e8 & 0xFF},
	{0xb8e9 & 0xFF, 0xb8ff & 0xFF},
	{0xb900 & 0xFF, 0xb903 & 0xFF},
	{0xb904 & 0xFF, 0xb904 & 0xFF},
	{0xb905 & 0xFF, 0xb91f & 0xFF},
	{0xb920 & 0xFF, 0xb920 & 0xFF},
	{0xb921 & 0xFF, 0xb93b & 0xFF},
	{0xb93c & 0xFF, 0xb93c & 0xFF},
	{0xb93d & 0xFF, 0xb957 & 0xFF},
	{0xb958 & 0xFF, 0xb958 & 0xFF},
	{0xb959 & 0xFF, 0xb973 & 0xFF},
	{0xb974 & 0xFF, 0xb974 & 0xFF},
	{0xb975 & 0xFF, 0xb98f & 0xFF},
	{0xb990 & 0xFF, 0xb990 & 0xFF},
	{0xb991 & 0xFF, 0xb9ab & 0xFF},
	{0xb9ac & 0xFF, 0xb9ac & 0xFF},
	{0xb9ad & 0xFF, 0xb9c7 & 0xFF},
	{0xb9c8 & 0xFF, 0xb9c8 & 0xFF},
	{0xb9c9 & 0xFF, 0xb9e3 & 0xFF},
	{0xb9e4 & 0xFF, 0xb9e4 & 0xFF},
	{0xb9e5 & 0xFF, 0xb9ff & 0xFF},
	{0xba00 & 0xFF, 0xba00 & 0xFF},
	{0xba01 & 0xFF, 0xba1b & 0xFF},
	{0xba1c & 0xFF, 0xba1c & 0xFF},
	{0xba1d & 0xFF, 0xba37 & 0xFF},
	{0xba38 & 0xFF, 0xba38 & 0xFF},
	{0xba39 & 0xFF, 0xba53 & 0xFF},
	{0xba54 & 0xFF, 0xba54 & 0xFF},
	{0xba55 & 0xFF, 0xba6f & 0xFF},
	{0xba70 & 0xFF, 0xba70 & 0xFF},
	{0xba71 & 0xFF, 0xba8b & 0xFF},
	{0xba8c & 0xFF, 0xba8c & 0xFF},
	{0xba8d & 0xFF, 0xbaa7 & 0xFF},
	{0xbaa8 & 0xFF, 0xbaa8 & 0xFF},
	{0xbaa9 & 0xFF, 0xbac3 & 0xFF},
	{0xbac4 & 0xFF, 0xbac4 & 0xFF},
	{0xbac5 & 0xFF, 0xbadf & 0xFF},
	{0xbae0 & 0xFF, 0xbae0 & 0xFF},
	{0xbae1 & 0xFF, 0xbafb & 0xFF},
	{0xbafc & 0xFF, 0xbafc & 0xFF},
	{0xbafd & 0xFF, 0xbaff & 0xFF},
	{0xbb00 & 0xFF, 0xbb17 & 0xFF},
	{0xbb18 & 0xFF, 0xbb18 & 0xFF},
	{0xbb19 & 0xFF, 0xbb33 & 0xFF},
	{0xbb34 & 0xFF, 0xbb34 & 0xFF},
	{0xbb35 & 0xFF, 0xbb4f & 0xFF},
	{0xbb50 & 0xFF, 0xbb50 & 0xFF},
	{0xbb51 & 0xFF, 0xbb6b & 0xFF},
	{0xbb6c & 0xFF, 0xbb6c & 0xFF},
	{0xbb6d & 0xFF, 0xbb87 & 0xFF},
	{0xbb88 & 0xFF, 0xbb88 & 0xFF},
	{0xbb89 & 0xFF, 0xbba3 & 0xFF},
	{0xbba4 & 0xFF, 0xbba4 & 0xFF},
	{0xbba5 & 0xFF, 0xbbbf & 0xFF},
	{0xbbc0 & 0xFF, 0xbbc0 & 0xFF},
	{0xbbc1 & 0xFF, 0xbbdb & 0xFF},
	{0xbbdc & 0xFF, 0xbbdc & 0xFF},
	{0xbbdd & 0xFF, 0xbbf7 & 0xFF},
	{0xbbf8 & 0xFF, 0xbbf8 & 0xFF},
	{0xbbf9 & 0xFF, 0xbbff & 0xFF},
	{0xbc00 & 0xFF, 0xbc13 & 0xFF},
	{0xbc14 & 0xFF, 0xbc14 & 0xFF},
	{0xbc15 & 0xFF, 0xbc2f & 0xFF},
	{0xbc30 & 0xFF, 0xbc30 & 0xFF},
	{0xbc31 & 0xFF, 0xbc4b & 0xFF},
	{0xbc4c & 0xFF, 0xbc4c & 0xFF},
	{0xbc4d & 0xFF, 0xbc67 & 0xFF},
	{0xbc68 & 0xFF, 0xbc68 & 0xFF},
	{0xbc69 & 0xFF, 0xbc83 & 0xFF},
	{0xbc84 & 0xFF, 0xbc84 & 0xFF},
	{0xbc85 & 0xFF, 0xbc9f & 0xFF},
	{0xbca0 & 0xFF, 0xbca0 & 0xFF},
	{0xbca1 & 0xFF, 0xbcbb & 0xFF},
	{0xbcbc & 0xFF, 0xbcbc & 0xFF},
	{0xbcbd & 0xFF, 0xbcd7 & 0xFF},
	{0xbcd8 & 0xFF, 0xbcd8 & 0xFF},
	{0xbcd9 & 0xFF, 0xbcf3 & 0xFF},
	{0xbcf4 & 0xFF, 0xbcf4 & 0xFF},
	{0xbcf5 & 0xFF, 0xbcff & 0xFF},
	{0xbd00 & 0xFF, 0xbd0f & 0xFF},
	{0xbd10 & 0xFF, 0xbd10 & 0xFF},
	{0xbd11 & 0xFF, 0xbd2b & 0xFF},
	{0xbd2c & 0xFF, 0xbd2c & 0xFF},
	{0xbd2d & 0xFF, 0xbd47 & 0xFF},
	{0xbd48 & 0xFF, 0xbd48 & 0xFF},
	{0xbd49 & 0xFF, 0xbd63 & 0xFF},
	{0xbd64 & 0xFF, 0xbd64 & 0xFF},
	{0xbd65 & 0xFF, 0xbd7f & 0xFF},
	{0xbd80 & 0xFF, 0xbd80 & 0xFF},
	{0xbd81 & 0xFF, 0xbd9b & 0xFF},
	{0xbd9c & 0xFF, 0xbd9c & 0xFF},
	{0xbd9d & 0xFF, 0xbdb7 & 0xFF},
	{0xbdb8 & 0xFF, 0xbdb8 & 0xFF},
	{0xbdb9 & 0xFF, 0xbdd3 & 0xFF},
	{0xbdd4 & 0xFF, 0xbdd4 & 0xFF},
	{0xbdd5 & 0xFF, 0xbdef & 0xFF},
	{0xbdf0 & 0xFF, 0xbdf0 & 0xFF},
	{0xbdf1 & 0xFF, 0xbdff & 0xFF},
	{0xbe00 & 0xFF, 0xbe0b & 0xFF},
	{0xbe0c & 0xFF, 0xbe0c & 0xFF},
	{0xbe0d & 0xFF, 0xbe27 & 0xFF},
	{0xbe28 & 0xFF, 0xbe28 & 0xFF},
	{0xbe29 & 0xFF, 0xbe43 & 0xFF},
	{0xbe44 & 0xFF, 0xbe44 & 0xFF},
	{0xbe45 & 0xFF, 0xbe5f & 0xFF},
	{0xbe60 & 0xFF, 0xbe60 & 0xFF},
	{0xbe61 & 0xFF, 0xbe7b & 0xFF},
	{0xbe7c & 0xFF, 0xbe7c & 0xFF},
	{0xbe7d & 0xFF, 0xbe97 & 0xFF},
	{0xbe98 & 0xFF, 0xbe98 & 0xFF},
	{0xbe99 & 0xFF, 0xbeb3 & 0xFF},
	{0xbeb4 & 0xFF, 0xbeb4 & 0xFF},
	{0xbeb5 & 0xFF, 0xbecf & 0xFF},
	{0xbed0 & 0xFF, 0xbed0 & 0xFF},
	{0xbed1 & 0xFF, 0xbeeb & 0xFF},
	{0xbeec & 0xFF, 0xbeec & 0xFF},
	{0xbeed & 0xFF, 0xbeff & 0xFF},
	{0xbf00 & 0xFF, 0xbf07 & 0xFF},
	{0xbf08 & 0xFF, 0xbf08 & 0xFF},
	{0xbf09 & 0xFF, 0xbf23 & 0xFF},
	{0xbf24 & 0xFF, 0xbf24 & 0xFF},
	{0xbf25 & 0xFF, 0xbf3f & 0xFF},
	{0xbf40 & 0xFF, 0xbf40 & 0xFF},
	{0xbf41 & 0xFF, 0xbf5b & 0xFF},
	{0xbf5c & 0xFF, 0xbf5c & 0xFF},
	{0xbf5d & 0xFF, 0xbf77 & 0xFF},
	{0xbf78 & 0xFF, 0xbf78 & 0xFF},
	{0xbf79 & 0xFF, 0xbf93 & 0xFF},
	{0xbf94 & 0xFF, 0xbf94 & 0xFF},
	{0xbf95 & 0xFF, 0xbfaf & 0xFF},
	{0xbfb0 & 0xFF, 0xbfb0 & 0xFF},
	{0xbfb1 & 0xFF, 0xbfcb & 0xFF},
	{0xbfcc & 0xFF, 0xbfcc & 0xFF},
	{0xbfcd & 0xFF, 0xbfe7 & 0xFF},
	{0xbfe8 & 0xFF, 0xbfe8 & 0xFF},
	{0xbfe9 & 0xFF, 0xbfff & 0xFF},
	{0xc000 & 0xFF, 0xc003 & 0xFF},
	{0xc004 & 0xFF, 0xc004 & 0xFF},
	{0xc005 & 0xFF, 0xc01f & 0xFF},
	{0xc020 & 0xFF, 0xc020 & 0xFF},
	{0xc021 & 0xFF, 0xc03b & 0xFF},
	{0xc03c & 0xFF, 0xc03c & 0xFF},
	{0xc03d & 0xFF, 0xc057 & 0xFF},
	{0xc058 & 0xFF, 0xc058 & 0xFF},
	{0xc059 & 0xFF, 0xc073 & 0xFF},
	{0xc074 & 0xFF, 0xc074 & 0xFF},
	{0xc075 & 0xFF, 0xc08f & 0xFF},
	{0xc090 & 0xFF, 0xc090 & 0xFF},
	{0xc091 & 0xFF, 0xc0ab & 0xFF},
	{0xc0ac & 0xFF, 0xc0ac & 0xFF},
	{0xc0ad & 0xFF, 0xc0c7 & 0xFF},
	{0xc0c8 & 0xFF, 0xc0c8 & 0xFF},
	{0xc0c9 & 0xFF, 0xc0e3 & 0xFF},
	{0xc0e4 & 0xFF, 0xc0e4 & 0xFF},
	{0xc0e5 & 0xFF, 0xc0ff & 0xFF},
	{0xc100 & 0xFF, 0xc100 & 0xFF},
	{0xc101 & 0xFF, 0xc11b & 0xFF},
	{0xc11c & 0xFF, 0xc11c & 0xFF},
	{0xc11d & 0xFF, 0xc137 & 0xFF},
	{0xc138 & 0xFF, 0xc138 & 0xFF},
	{0xc139 & 0xFF, 0xc153 & 0xFF},
	{0xc154 & 0xFF, 0xc154 & 0xFF},
	{0xc155 & 0xFF, 0xc16f & 0xFF},
	{0xc170 & 0xFF, 0xc170 & 0xFF},
	{0xc171 & 0xFF, 0xc18b & 0xFF},
	{0xc18c & 0xFF, 0xc18c & 0xFF},
	{0xc18d & 0xFF, 0xc1a7 & 0xFF},
	{0xc1a8 & 0xFF, 0xc1a8 & 0xFF},
	{0xc1a9 & 0xFF, 0xc1c3 & 0xFF},
	{0xc1c4 & 0xFF, 0xc1c4 & 0xFF},
	{0xc1c5 & 0xFF, 0xc1df & 0xFF},
	{0xc1e0 & 0xFF, 0xc1e0 & 0xFF},
	{0xc1e1 & 0xFF, 0xc1fb & 0xFF},
	{0xc1fc & 0xFF, 0xc1fc & 0xFF},
	{0xc1fd & 0xFF, 0xc1ff & 0xFF},
	{0xc200 & 0xFF, 0xc217 & 0xFF},
	{0xc218 & 0xFF, 0xc218 & 0xFF},
	{0xc219 & 0xFF, 0xc233 & 0xFF},
	{0xc234 & 0xFF, 0xc234 & 0xFF},
	{0xc235 & 0xFF, 0xc24f & 0xFF},
	{0xc250 & 0xFF, 0xc250 & 0xFF},
	{0xc251 & 0xFF, 0xc26b & 0xFF},
	{0xc26c & 0xFF, 0xc26c & 0xFF},
	{0xc26d & 0xFF, 0xc287 & 0xFF},
	{0xc288 & 0xFF, 0xc288 & 0xFF},
	{0xc289 & 0xFF, 0xc2a3 & 0xFF},
	{0xc2a4 & 0xFF, 0xc2a4 & 0xFF},
	{0xc2a5 & 0xFF, 0xc2bf & 0xFF},
	{0xc2c0 & 0xFF, 0xc2c0 & 0xFF},
	{0xc2c1 & 0xFF, 0xc2db & 0xFF},
	{0xc2dc & 0xFF, 0xc2dc & 0xFF},
	{0xc2dd & 0xFF, 0xc2f7 & 0xFF},
	{0xc2f8 & 0xFF, 0xc2f8 & 0xFF},
	{0xc2f9 & 0xFF, 0xc2ff & 0xFF},
	{0xc300 & 0xFF, 0xc313 & 0xFF},
	{0xc314 & 0xFF, 0xc314 & 0xFF},
	{0xc315 & 0xFF, 0xc32f & 0xFF},
	{0xc330 & 0xFF, 0xc330 & 0xFF},
	{0xc331 & 0xFF, 0xc34b & 0xFF},
	{0xc34c & 0xFF, 0xc34c & 0xFF},
	{0xc34d & 0xFF, 0xc367 & 0xFF},
	{0xc368 & 0xFF, 0xc368 & 0xFF},
	{0xc369 & 0xFF, 0xc383 & 0xFF},
	{0xc384 & 0xFF, 0xc384 & 0xFF},
	{0xc385 & 0xFF, 0xc39f & 0xFF},
	{0xc3a0 & 0xFF, 0xc3a0 & 0xFF},
	{0xc3a1 & 0xFF, 0xc3bb & 0xFF},
	{0xc3bc & 0xFF, 0xc3bc & 0xFF},
	{0xc3bd & 0xFF, 0xc3d7 & 0xFF},
	{0xc3d8 & 0xFF, 0xc3d8 & 0xFF},
	{0xc3d9 & 0xFF, 0xc3f3 & 0xFF},
	{0xc3f4 & 0xFF, 0xc3f4 & 0xFF},
	{0xc3f5 & 0xFF, 0xc3ff & 0xFF},
	{0xc400 & 0xFF, 0xc40f & 0xFF},
	{0xc410 & 0xFF, 0xc410 & 0xFF},
	{0xc411 & 0xFF, 0xc42b & 0xFF},
	{0xc42c & 0xFF, 0xc42c & 0xFF},
	{0xc42d & 0xFF, 0xc447 & 0xFF},
	{0xc448 & 0xFF, 0xc448 & 0xFF},
	{0xc449 & 0xFF, 0xc463 & 0xFF},
	{0xc464 & 0xFF, 0xc464 & 0xFF},
	{0xc465 & 0xFF, 0xc47f & 0xFF},
	{0xc480 & 0xFF, 0xc480 & 0xFF},
	{0xc481 & 0xFF, 0xc49b & 0xFF},
	{0xc49c & 0xFF, 0xc49c & 0xFF},
	{0xc49d & 0xFF, 0xc4b7 & 0xFF},
	{0xc4b8 & 0xFF, 0xc4b8 & 0xFF},
	{0xc4b9 & 0xFF, 0xc4d3 & 0xFF},
	{0xc4d4 & 0xFF, 0xc4d4 & 0xFF},
	{0xc4d5 & 0xFF, 0xc4ef & 0xFF},
	{0xc4f0 & 0xFF, 0xc4f0 & 0xFF},
	{0xc4f1 & 0xFF, 0xc4ff & 0xFF},
	{0xc500 & 0xFF, 0xc50b & 0xFF},
	{0xc50c & 0xFF, 0xc50c & 0xFF},
	{0xc50d & 0xFF, 0xc527 & 0xFF},
	{0xc528 & 0xFF, 0xc528 & 0xFF},
	{0xc529 & 0xFF, 0xc543 & 0xFF},
	{0xc544 & 0xFF, 0xc544 & 0xFF},
	{0xc545 & 0xFF, 0xc55f & 0xFF},
	{0xc560 & 0xFF, 0xc560 & 0xFF},
	{0xc561 & 0xFF, 0xc57b & 0xFF},
	{0xc57c & 0xFF, 0xc57c & 0xFF},
	{0xc57d & 0xFF, 0xc597 & 0xFF},
	{0xc598 & 0xFF, 0xc598 & 0xFF},
	{0xc599 & 0xFF, 0xc5b3 & 0xFF},
	{0xc5b4 & 0xFF, 0xc5b4 & 0xFF},
	{0xc5b5 & 0xFF, 0xc5cf & 0xFF},
	{0xc5d0 & 0xFF, 0xc5d0 & 0xFF},
	{0xc5d1 & 0xFF, 0xc5eb & 0xFF},
	{0xc5ec & 0xFF, 0xc5ec & 0xFF},
	{0xc5ed & 0xFF, 0xc5ff & 0xFF},
	{0xc600 & 0xFF, 0xc607 & 0xFF},
	{0xc608 & 0xFF, 0xc608 & 0xFF},
	{0xc609 & 0xFF, 0xc623 & 0xFF},
	{0xc624 & 0xFF, 0xc624 & 0xFF},
	{0xc625 & 0xFF, 0xc63f & 0xFF},
	{0xc640 & 0xFF, 0xc640 & 0xFF},
	{0xc641 & 0xFF, 0xc65b & 0xFF},
	{0xc65c & 0xFF, 0xc65c & 0xFF},
	{0xc65d & 0xFF, 0xc677 & 0xFF},
	{0xc678 & 0xFF, 0xc678 & 0xFF},
	{0xc679 & 0xFF, 0xc693 & 0xFF},
	{0xc694 & 0xFF, 0xc694 & 0xFF},
	{0xc695 & 0xFF, 0xc6af & 0xFF},
	{0xc6b0 & 0xFF, 0xc6b0 & 0xFF},
	{0xc6b1 & 0xFF, 0xc6cb & 0xFF},
	{0xc6cc & 0xFF, 0xc6cc & 0xFF},
	{0xc6cd & 0xFF, 0xc6e7 & 0xFF},
	{0xc6e8 & 0xFF, 0xc6e8 & 0xFF},
	{0xc6e9 & 0xFF, 0xc6ff & 0xFF},
	{0xc700 & 0xFF, 0xc703 & 0xFF},
	{0xc704 & 0xFF, 0xc704 & 0xFF},
	{0xc705 & 0xFF, 0xc71f & 0xFF},
	{0xc720 & 0xFF, 0xc720 & 0xFF},
	{0xc721 & 0xFF, 0xc73b & 0xFF},
	{0xc73c & 0xFF, 0xc73c & 0xFF},
	{0xc73d & 0xFF, 0xc757 & 0xFF},
	{0xc758 & 0xFF, 0xc758 & 0xFF},
	{0xc759 & 0xFF, 0xc773 & 0xFF},
	{0xc774 & 0xFF, 0xc774 & 0xFF},
	{0xc775 & 0xFF, 0xc78f & 0xFF},
	{0xc790 & 0xFF, 0xc790 & 0xFF},
	{0xc791 & 0xFF, 0xc7ab & 0xFF},
	{0xc7ac & 0xFF, 0xc7ac & 0xFF},
	{0xc7ad & 0xFF, 0xc7c7 & 0xFF},
	{0xc7c8 & 0xFF, 0xc7c8 & 0xFF},
	{0xc7c9 & 0xFF, 0xc7e3 & 0xFF},
	{0xc7e4 & 0xFF, 0xc7e4 & 0xFF},
	{0xc7e5 & 0xFF, 0xc7ff & 0xFF},
	{0xc800 & 0xFF, 0xc800 & 0xFF},
	{0xc801 & 0xFF, 0xc81b & 0xFF},
	{0xc81c & 0xFF, 0xc81c & 0xFF},
	{0xc81d & 0xFF, 0xc837 & 0xFF},
	{0xc838 & 0xFF, 0xc838 & 0xFF},
	{0xc839 & 0xFF, 0xc853 & 0xFF},
	{0xc854 & 0xFF, 0xc854 & 0xFF},
	{0xc855 & 0xFF, 0xc86f & 0xFF},
	{0xc870 & 0xFF, 0xc870 & 0xFF},
	{0xc871 & 0xFF, 0xc88b & 0xFF},
	{0xc88c & 0xFF, 0xc88c & 0xFF},
	{0xc88d & 0xFF, 0xc8a7 & 0xFF},
	{0xc8a8 & 0xFF, 0xc8a8 & 0xFF},
	{0xc8a9 & 0xFF, 0xc8c3 & 0xFF},
	{0xc8c4 & 0xFF, 0xc8c4 & 0xFF},
	{0xc8c5 & 0xFF, 0xc8df & 0xFF},
	{0xc8e0 & 0xFF, 0xc8e0 & 0xFF},
	{0xc8e1 & 0xFF, 0xc8fb & 0xFF},
	{0xc8fc & 0xFF, 0xc8fc & 0xFF},
	{0xc8fd & 0xFF, 0xc8ff & 0xFF},
	{0xc900 & 0xFF, 0xc917 & 0xFF},
	{0xc918 & 0xFF, 0xc918 & 0xFF},
	{0xc919 & 0xFF, 0xc933 & 0xFF},
	{0xc934 & 0xFF, 0xc934 & 0xFF},
	{0xc935 & 0xFF, 0xc94f & 0xFF},
	{0xc950 & 0xFF, 0xc950 & 0xFF},
	{0xc951 & 0xFF, 0xc96b & 0xFF},
	{0xc96c & 0xFF, 0xc96c & 0xFF},
	{0xc96d & 0xFF, 0xc987 & 0xFF},
	{0xc988 & 0xFF, 0xc988 & 0xFF},
	{0xc989 & 0xFF, 0xc9a3 & 0xFF},
	{0xc9a4 & 0xFF, 0xc9a4 & 0xFF},
	{0xc9a5 & 0xFF, 0xc9bf & 0xFF},
	{0xc9c0 & 0xFF, 0xc9c0 & 0xFF},
	{0xc9c1 & 0xFF, 0xc9db & 0xFF},
	{0xc9dc & 0xFF, 0xc9dc & 0xFF},
	{0xc9dd & 0xFF, 0xc9f7 & 0xFF},
	{0xc9f8 & 0xFF, 0xc9f8 & 0xFF},
	{0xc9f9 & 0xFF, 0xc9ff & 0xFF},
	{0xca00 & 0xFF, 0xca13 & 0xFF},
	{0xca14 & 0xFF, 0xca14 & 0xFF},
	{0xca15 & 0xFF, 0xca2f & 0xFF},
	{0xca30 & 0xFF, 0xca30 & 0xFF},
	{0xca31 & 0xFF, 0xca4b & 0xFF},
	{0xca4c & 0xFF, 0xca4c & 0xFF},
	{0xca4d & 0xFF, 0xca67 & 0xFF},
	{0xca68 & 0xFF, 0xca68 & 0xFF},
	{0xca69 & 0xFF, 0xca83 & 0xFF},
	{0xca84 & 0xFF, 0xca84 & 0xFF},
	{0xca85 & 0xFF, 0xca9f & 0xFF},
	{0xcaa0 & 0xFF, 0xcaa0 & 0xFF},
	{0xcaa1 & 0xFF, 0xcabb & 0xFF},
	{0xcabc & 0xFF, 0xcabc & 0xFF},
	{0xcabd & 0xFF, 0xcad7 & 0xFF},
	{0xcad8 & 0xFF, 0xcad8 & 0xFF},
	{0xcad9 & 0xFF, 0xcaf3 & 0xFF},
	{0xcaf4 & 0xFF, 0xcaf4 & 0xFF},
	{0xcaf5 & 0xFF, 0xcaff & 0xFF},
	{0xcb00 & 0xFF, 0xcb0f & 0xFF},
	{0xcb10 & 0xFF, 0xcb10 & 0xFF},
	{0xcb11 & 0xFF, 0xcb2b & 0xFF},
	{0xcb2c & 0xFF, 0xcb2c & 0xFF},
	{0xcb2d & 0xFF, 0xcb47 & 0xFF},
	{0xcb48 & 0xFF, 0xcb48 & 0xFF},
	{0xcb49 & 0xFF, 0xcb63 & 0xFF},
	{0xcb64 & 0xFF, 0xcb64 & 0xFF},
	{0xcb65 & 0xFF, 0xcb7f & 0xFF},
	{0xcb80 & 0xFF, 0xcb80 & 0xFF},
	{0xcb81 & 0xFF, 0xcb9b & 0xFF},
	{0xcb9c & 0xFF, 0xcb9c & 0xFF},
	{0xcb9d & 0xFF, 0xcbb7 & 0xFF},
	{0xcbb8 & 0xFF, 0xcbb8 & 0xFF},
	{0xcbb9 & 0xFF, 0xcbd3 & 0xFF},
	{0xcbd4 & 0xFF, 0xcbd4 & 0xFF},
	{0xcbd5 & 0xFF, 0xcbef & 0xFF},
	{0xcbf0 & 0xFF, 0xcbf0 & 0xFF},
	{0xcbf1 & 0xFF, 0xcbff & 0xFF},
	{0xcc00 & 0xFF, 0xcc0b & 0xFF},
	{0xcc0c & 0xFF, 0xcc0c & 0xFF},
	{0xcc0d & 0xFF, 0xcc27 & 0xFF},
	{0xcc28 & 0xFF, 0xcc28 & 0xFF},
	{0xcc29 & 0xFF, 0xcc43 & 0xFF},
	{0xcc44 & 0xFF, 0xcc44 & 0xFF},
	{0xcc45 & 0xFF, 0xcc5f & 0xFF},
	{0xcc60 & 0xFF, 0xcc60 & 0xFF},
	{0xcc61 & 0xFF, 0xcc7b & 0xFF},
	{0xcc7c & 0xFF, 0xcc7c & 0xFF},
	{0xcc7d & 0xFF, 0xcc97 & 0xFF},
	{0xcc98 & 0xFF, 0xcc98 & 0xFF},
	{0xcc99 & 0xFF, 0xccb3 & 0xFF},
	{0xccb4 & 0xFF, 0xccb4 & 0xFF},
	{0xccb5 & 0xFF, 0xcccf & 0xFF},
	{0xccd0 & 0xFF, 0xccd0 & 0xFF},
	{0xccd1 & 0xFF, 0xcceb & 0xFF},
	{0xccec & 0xFF, 0xccec & 0xFF},
	{0xcced & 0xFF, 0xccff & 0xFF},
	{0xcd00 & 0xFF, 0xcd07 & 0xFF},
	{0xcd08 & 0xFF, 0xcd08 & 0xFF},
	{0xcd09 & 0xFF, 0xcd23 & 0xFF},
	{0xcd24 & 0xFF, 0xcd24 & 0xFF},
	{0xcd25 & 0xFF, 0xcd3f & 0xFF},
	{0xcd40 & 0xFF, 0xcd40 & 0xFF},
	{0xcd41 & 0xFF, 0xcd5b & 0xFF},
	{0xcd5c & 0xFF, 0xcd5c & 0xFF},
	{0xcd5d & 0xFF, 0xcd77 & 0xFF},
	{0xcd78 & 0xFF, 0xcd78 & 0xFF},
	{0xcd79 & 0xFF, 0xcd93 & 0xFF},
	{0xcd94 & 0xFF, 0xcd94 & 0xFF},
	{0xcd95 & 0xFF, 0xcdaf & 0xFF},
	{0xcdb0 & 0xFF, 0xcdb0 & 0xFF},
	{0xcdb1 & 0xFF, 0xcdcb & 0xFF},
	{0xcdcc & 0xFF, 0xcdcc & 0xFF},
	{0xcdcd & 0xFF, 0xcde7 & 0xFF},
	{0xcde8 & 0xFF, 0xcde8 & 0xFF},
	{0xcde9 & 0xFF, 0xcdff & 0xFF},
	{0xce00 & 0xFF, 0xce03 & 0xFF},
	{0xce04 & 0xFF, 0xce04 & 0xFF},
	{0xce05 & 0xFF, 0xce1f & 0xFF},
	{0xce20 & 0xFF, 0xce20 & 0xFF},
	{0xce21 & 0xFF, 0xce3b & 0xFF},
	{0xce3c & 0xFF, 0xce3c & 0xFF},
	{0xce3d & 0xFF, 0xce57 & 0xFF},
	{0xce58 & 0xFF, 0xce58 & 0xFF},
	{0xce59 & 0xFF, 0xce73 & 0xFF},
	{0xce74 & 0xFF, 0xce74 & 0xFF},
	{0xce75 & 0xFF, 0xce8f & 0xFF},
	{0xce90 & 0xFF, 0xce90 & 0xFF},
	{0xce91 & 0xFF, 0xceab & 0xFF},
	{0xceac & 0xFF, 0xceac & 0xFF},
	{0xcead & 0xFF, 0xcec7 & 0xFF},
	{0xcec8 & 0xFF, 0xcec8 & 0xFF},
	{0xcec9 & 0xFF, 0xcee3 & 0xFF},
	{0xcee4 & 0xFF, 0xcee4 & 0xFF},
	{0xcee5 & 0xFF, 0xceff & 0xFF},
	{0xcf00 & 0xFF, 0xcf00 & 0xFF},
	{0xcf01 & 0xFF, 0xcf1b & 0xFF},
	{0xcf1c & 0xFF, 0xcf1c & 0xFF},
	{0xcf1d & 0xFF, 0xcf37 & 0xFF},
	{0xcf38 & 0xFF, 0xcf38 & 0xFF},
	{0xcf39 & 0xFF, 0xcf53 & 0xFF},
	{0xcf54 & 0xFF, 0xcf54 & 0xFF},
	{0xcf55 & 0xFF, 0xcf6f & 0xFF},
	{0xcf70 & 0xFF, 0xcf70 & 0xFF},
	{0xcf71 & 0xFF, 0xcf8b & 0xFF},
	{0xcf8c & 0xFF, 0xcf8c & 0xFF},
	{0xcf8d & 0xFF, 0xcfa7 & 0xFF},
	{0xcfa8 & 0xFF, 0xcfa8 & 0xFF},
	{0xcfa9 & 0xFF, 0xcfc3 & 0xFF},
	{0xcfc4 & 0xFF, 0xcfc4 & 0xFF},
	{0xcfc5 & 0xFF, 0xcfdf & 0xFF},
	{0xcfe0 & 0xFF, 0xcfe0 & 0xFF},
	{0xcfe1 & 0xFF, 0xcffb & 0xFF},
	{0xcffc & 0xFF, 0xcffc & 0xFF},
	{0xcffd & 0xFF, 0xcfff & 0xFF},
	{0xd000 & 0xFF, 0xd017 & 0xFF},
	{0xd018 & 0xFF, 0xd018 & 0xFF},
	{0xd019 & 0xFF, 0xd033 & 0xFF},
	{0xd034 & 0xFF, 0xd034 & 0xFF},
	{0xd035 & 0xFF, 0xd04f & 0xFF},
	{0xd050 & 0xFF, 0xd050 & 0xFF},
	{0xd051 & 0xFF, 0xd06b & 0xFF},
	{0xd06c & 0xFF, 0xd06c & 0xFF},
	{0xd06d & 0xFF, 0xd087 & 0xFF},
	{0xd088 & 0xFF, 0xd088 & 0xFF},
	{0xd089 & 0xFF, 0xd0a3 & 0xFF},
	{0xd0a4 & 0xFF, 0xd0a4 & 0xFF},
	{0xd0a5 & 0xFF, 0xd0bf & 0xFF},
	{0xd0c0 & 0xFF, 0xd0c0 & 0xFF},
	{0xd0c1 & 0xFF, 0xd0db & 0xFF},
	{0xd0dc & 0xFF, 0xd0dc & 0xFF},
	{0xd0dd & 0xFF, 0xd0f7 & 0xFF},
	{0xd0f8 & 0xFF, 0xd0f8 & 0xFF},
	{0xd0f9 & 0xFF, 0xd0ff & 0xFF},
	{0xd100 & 0xFF, 0xd113 & 0xFF},
	{0xd114 & 0xFF, 0xd114 & 0xFF},
	{0xd115 & 0xFF, 0xd12f & 0xFF},
	{0xd130 & 0xFF, 0xd130 & 0xFF},
	{0xd131 & 0xFF, 0xd14b & 0xFF},
	{0xd14c & 0xFF, 0xd14c & 0xFF},
	{0xd14d & 0xFF, 0xd167 & 0xFF},
	{0xd168 & 0xFF, 0xd168 & 0xFF},
	{0xd169 & 0xFF, 0xd183 & 0xFF},
	{0xd184 & 0xFF, 0xd184 & 0xFF},
	{0xd185 & 0xFF, 0xd19f & 0xFF},
	{0xd1a0 & 0xFF, 0xd1a0 & 0xFF},
	{0xd1a1 & 0xFF, 0xd1bb & 0xFF},
	{0xd1bc & 0xFF, 0xd1bc & 0xFF},
	{0xd1bd & 0xFF, 0xd1d7 & 0xFF},
	{0xd1d8 & 0xFF, 0xd1d8 & 0xFF},
	{0xd1d9 & 0xFF, 0xd1f3 & 0xFF},
	{0xd1f4 & 0xFF, 0xd1f4 & 0xFF},
	{0xd1f5 & 0xFF, 0xd1ff & 0xFF},
	{0xd200 & 0xFF, 0xd20f & 0xFF},
	{0xd210 & 0xFF, 0xd210 & 0xFF},
	{0xd211 & 0xFF, 0xd22b & 0xFF},
	{0xd22c & 0xFF, 0xd22c & 0xFF},
	{0xd22d & 0xFF, 0xd247 & 0xFF},
	{0xd248 & 0xFF, 0xd248 & 0xFF},
	{0xd249 & 0xFF, 0xd263 & 0xFF},
	{0xd264 & 0xFF, 0xd264 & 0xFF},
	{0xd265 & 0xFF, 0xd27f & 0xFF},
	{0xd280 & 0xFF, 0xd280 & 0xFF},
	{0xd281 & 0xFF, 0xd29b & 0xFF},
	{0xd29c & 0xFF, 0xd29c & 0xFF},
	{0xd29d & 0xFF, 0xd2b7 & 0xFF},
	{0xd2b8 & 0xFF, 0xd2b8 & 0xFF},
	{0xd2b9 & 0xFF, 0xd2d3 & 0xFF},
	{0xd2d4 & 0xFF, 0xd2d4 & 0xFF},
	{0xd2d5 & 0xFF, 0xd2ef & 0xFF},
	{0xd2f0 & 0xFF, 0xd2f0 & 0xFF},
	{0xd2f1 & 0xFF, 0xd2ff & 0xFF},
	{0xd300 & 0xFF, 0xd30b & 0xFF},
	{0xd30c & 0xFF, 0xd30c & 0xFF},
	{0xd30d & 0xFF, 0xd327 & 0xFF},
	{0xd328 & 0xFF, 0xd328 & 0xFF},
	{0xd329 & 0xFF, 0xd343 & 0xFF},
	{0xd344 & 0xFF, 0xd344 & 0xFF},
	{0xd345 & 0xFF, 0xd35f & 0xFF},
	{0xd360 & 0xFF, 0xd360 & 0xFF},
	{0xd361 & 0xFF, 0xd37b & 0xFF},
	{0xd37c & 0xFF, 0xd37c & 0xFF},
	{0xd37d & 0xFF, 0xd397 & 0xFF},
	{0xd398 & 0xFF, 0xd398 & 0xFF},
	{0xd399 & 0xFF, 0xd3b3 & 0xFF},
	{0xd3b4 & 0xFF, 0xd3b4 & 0xFF},
	{0xd3b5 & 0xFF, 0xd3cf & 0xFF},
	{0xd3d0 & 0xFF, 0xd3d0 & 0xFF},
	{0xd3d1 & 0xFF, 0xd3eb & 0xFF},
	{0xd3ec & 0xFF, 0xd3ec & 0xFF},
	{0xd3ed & 0xFF, 0xd3ff & 0xFF},
	{0xd400 & 0xFF, 0xd407 & 0xFF},
	{0xd408 & 0xFF, 0xd408 & 0xFF},
	{0xd409 & 0xFF, 0xd423 & 0xFF},
	{0xd424 & 0xFF, 0xd424 & 0xFF},
	{0xd425 & 0xFF, 0xd43f & 0xFF},
	{0xd440 & 0xFF, 0xd440 & 0xFF},
	{0xd441 & 0xFF, 0xd45b & 0xFF},
	{0xd45c & 0xFF, 0xd45c & 0xFF},
	{0xd45d & 0xFF, 0xd477 & 0xFF},
	{0xd478 & 0xFF, 0xd478 & 0xFF},
	{0xd479 & 0xFF, 0xd493 & 0xFF},
	{0xd494 & 0xFF, 0xd494 & 0xFF},
	{0xd495 & 0xFF, 0xd4af & 0xFF},
	{0xd4b0 & 0xFF, 0xd4b0 & 0xFF},
	{0xd4b1 & 0xFF, 0xd4cb & 0xFF},
	{0xd4cc & 0xFF, 0xd4cc & 0xFF},
	{0xd4cd & 0xFF, 0xd4e7 & 0xFF},
	{0xd4e8 & 0xFF, 0xd4e8 & 0xFF},
	{0xd4e9 & 0xFF, 0xd4ff & 0xFF},
	{0xd500 & 0xFF, 0xd503 & 0xFF},
	{0xd504 & 0xFF, 0xd504 & 0xFF},
	{0xd505 & 0xFF, 0xd51f & 0xFF},
	{0xd520 & 0xFF, 0xd520 & 0xFF},
	{0xd521 & 0xFF, 0xd53b & 0xFF},
	{0xd53c & 0xFF, 0xd53c & 0xFF},
	{0xd53d & 0xFF, 0xd557 & 0xFF},
	{0xd558 & 0xFF, 0xd558 & 0xFF},
	{0xd559 & 0xFF, 0xd573 & 0xFF},
	{0xd574 & 0xFF, 0xd574 & 0xFF},
	{0xd575 & 0xFF, 0xd58f & 0xFF},
	{0xd590 & 0xFF, 0xd590 & 0xFF},
	{0xd591 & 0xFF, 0xd5ab & 0xFF},
	{0xd5ac & 0xFF, 0xd5ac & 0xFF},
	{0xd5ad & 0xFF, 0xd5c7 & 0xFF},
	{0xd5c8 & 0xFF, 0xd5c8 & 0xFF},
	{0xd5c9 & 0xFF, 0xd5e3 & 0xFF},
	{0xd5e4 & 0xFF, 0xd5e4 & 0xFF},
	{0xd5e5 & 0xFF, 0xd5ff & 0xFF},
	{0xd600 & 0xFF, 0xd600 & 0xFF},
	{0xd601 & 0xFF, 0xd61b & 0xFF},
	{0xd61c & 0xFF, 0xd61c & 0xFF},
	{0xd61d & 0xFF, 0xd637 & 0xFF},
	{0xd638 & 0xFF, 0xd638 & 0xFF},
	{0xd639 & 0xFF, 0xd653 & 0xFF},
	{0xd654 & 0xFF, 0xd654 & 0xFF},
	{0xd655 & 0xFF, 0xd66f & 0xFF},
	{0xd670 & 0xFF, 0xd670 & 0xFF},
	{0xd671 & 0xFF, 0xd68b & 0xFF},
	{0xd68c & 0xFF, 0xd68c & 0xFF},
	{0xd68d & 0xFF, 0xd6a7 & 0xFF},
	{0xd6a8 & 0xFF, 0xd6a8 & 0xFF},
	{0xd6a9 & 0xFF, 0xd6c3 & 0xFF},
	{0xd6c4 & 0xFF, 0xd6c4 & 0xFF},
	{0xd6c5 & 0xFF, 0xd6df & 0xFF},
	{0xd6e0 & 0xFF, 0xd6e0 & 0xFF},
	{0xd6e1 & 0xFF, 0xd6fb & 0xFF},
	{0xd6fc & 0xFF, 0xd6fc & 0xFF},
	{0xd6fd & 0xFF, 0xd6ff & 0xFF},
	{0xd700 & 0xFF, 0xd717 & 0xFF},
	{0xd718 & 0xFF, 0xd718 & 0xFF},
	{0xd719 & 0xFF, 0xd733 & 0xFF},
	{0xd734 & 0xFF, 0xd734 & 0xFF},
	{0xd735 & 0xFF, 0xd74f & 0xFF},
	{0xd750 & 0xFF, 0xd750 & 0xFF},
	{0xd751 & 0xFF, 0xd76b & 0xFF},
	{0xd76c & 0xFF, 0xd76c & 0xFF},
	{0xd76d & 0xFF, 0xd787 & 0xFF},
	{0xd788 & 0xFF, 0xd788 & 0xFF},
	{0xd789 & 0xFF, 0xd7a3 & 0xFF},
	{0xd7b0 & 0xFF, 0xd7c6 & 0xFF},
	{0xd7cb & 0xFF, 0xd7fb & 0xFF},
	{0xfb1e & 0xFF, 0xfb1e & 0xFF},
	{0xfe00 & 0xFF, 0xfe0f & 0xFF},
	{0xfe20 & 0xFF, 0xfe2f & 0xFF},
	{0xfeff & 0xFF, 0xfeff & 0xFF},
	{0xff9e & 0xFF, 0xff9f & 0xFF},
	{0xfff0 & 0xFF, 0xfffb & 0xFF},
	{0x101fd & 0xFF, 0x101fd & 0xFF},
	{0x102e0 & 0xFF, 0x102e0 & 0xFF},
	{0x10376 & 0xFF, 0x1037a & 0xFF},
	{0x10a01 & 0xFF, 0x10a03 & 0xFF},
	{0x10a05 & 0xFF, 0x10a06 & 0xFF},
	{0x10a0c & 0xFF, 0x10a0f & 0xFF},
	{0x10a38 & 0xFF, 0x10a3a & 0xFF},
	{0x10a3f & 0xFF, 0x10a3f & 0xFF},
	{0x10ae5 & 0xFF, 0x10ae6 & 0xFF},
	{0x10d24 & 0xFF, 0x10d27 & 0xFF},
	{0x10eab & 0xFF, 0x10eac & 0xFF},
	{0x10efd & 0xFF, 0x10eff & 0xFF},
	{0x10f46 & 0xFF, 0x10f50 & 0xFF},
	{0x10f82 & 0xFF, 0x10f85 & 0xFF},
	{0x11000 & 0xFF, 0x11000 & 0xFF},
	{0x11001 & 0xFF, 0x11001 & 0xFF},
	{0x11002 & 0xFF, 0x11002 & 0xFF},
	{0x11038 & 0xFF, 0x11046 & 0xFF},
	{0x11070 & 0xFF, 0x11070 & 0xFF},
	{0x11073 & 0xFF, 0x11074 & 0xFF},
	{0x1107f & 0xFF, 0x11081 & 0xFF},
	{0x11082 & 0xFF, 0x11082 & 0xFF},
	{0x110b0 & 0xFF, 0x110b2 & 0xFF},
	{0x110b3 & 0xFF, 0x110b6 & 0xFF},
	{0x110b7 & 0xFF, 0x110b8 & 0xFF},
	{0x110b9 & 0xFF, 0x110ba & 0xFF},
	{0x110bd & 0xFF, 0x110bd & 0xFF},
	{0x110c2 & 0xFF, 0x110c2 & 0xFF},
	{0x110cd & 0xFF, 0x110cd & 0xFF},
	{0x11100 & 0xFF, 0x11102 & 0xFF},
	{0x11127 & 0xFF, 0x1112b & 0xFF},
	{0x1112c & 0xFF, 0x1112c & 0xFF},
	{0x1112d & 0xFF, 0x11134 & 0xFF},
	{0x11145 & 0xFF, 0x11146 & 0xFF},
	{0x11173 & 0xFF, 0x11173 & 0xFF},
	{0x11180 & 0xFF, 0x11181 & 0xFF},
	{0x11182 & 0xFF, 0x11182 & 0xFF},
	{0x111b3 & 0xFF, 0x111b5 & 0xFF},
	{0x111b6 & 0xFF, 0x111be & 0xFF},
	{0x111bf & 0xFF, 0x111c0 & 0xFF},
	{0x111c2 & 0xFF, 0x111c3 & 0xFF},
	{0x111c9 & 0xFF, 0x111cc & 0xFF},
	{0x111ce & 0xFF, 0x111ce & 0xFF},
	{0x111cf & 0xFF, 0x111cf & 0xFF},
	{0x1122c & 0xFF, 0x1122e & 0xFF},
	{0x1122f & 0xFF, 0x11231 & 0xFF},
	{0x11232 & 0xFF, 0x11233 & 0xFF},
	{0x11234 & 0xFF, 0x11234 & 0xFF},
	{0x11235 & 0xFF, 0x11235 & 0xFF},
	{0x11236 & 0xFF, 0x11237 & 0xFF},
	{0x1123e & 0xFF, 0x1123e & 0xFF},
	{0x11241 & 0xFF, 0x11241 & 0xFF},
	{0x112df & 0xFF, 0x112df & 0xFF},
	{0x112e0 & 0xFF, 0x112e2 & 0xFF},
	{0x112e3 & 0xFF, 0x112ea & 0xFF},
	{0x11300 & 0xFF, 0x11301 & 0xFF},
	{0x11302 & 0xFF, 0x11303 & 0xFF},
	{0x1133b & 0xFF, 0x1133c & 0xFF},
	{0x1133e & 0xFF, 0x1133e & 0xFF},
	{0x1133f & 0xFF, 0x1133f & 0xFF},
	{0x11340 & 0xFF, 0x11340 & 0xFF},
	{0x11341 & 0xFF, 0x11344 & 0xFF},
	{0x11347 & 0xFF, 0x11348 & 0xFF},
	{0x1134b & 0xFF, 0x1134d & 0xFF},
	{0x11357 & 0xFF, 0x11357 & 0xFF},
	{0x11362 & 0xFF, 0x11363 & 0xFF},
	{0x11366 & 0xFF, 0x1136c & 0xFF},
	{0x11370 & 0xFF, 0x11374 & 0xFF},
	{0x11435 & 0xFF, 0x11437 & 0xFF},
	{0x11438 & 0xFF, 0x1143f & 0xFF},
	{0x11440 & 0xFF, 0x11441 & 0xFF},
	{0x11442 & 0xFF, 0x11444 & 0xFF},
	{0x11445 & 0xFF, 0x11445 & 0xFF},
	{0x11446 & 0xFF, 0x11446 & 0xFF},
	{0x1145e & 0xFF, 0x1145e & 0xFF},
	{0x114b0 & 0xFF, 0x114b0 & 0xFF},
	{0x114b1 & 0xFF, 0x114b2 & 0xFF},
	{0x114b3 & 0xFF, 0x114b8 & 0xFF},
	{0x114b9 & 0xFF, 0x114b9 & 0xFF},
	{0x114ba & 0xFF, 0x114ba & 0xFF},
	{0x114bb & 0xFF, 0x114bc & 0xFF},
	{0x114bd & 0xFF, 0x114bd & 0xFF},
	{0x114be & 0xFF, 0x114be & 0xFF},
	{0x114bf & 0xFF, 0x114c0 & 0xFF},
	{0x114c1 & 0xFF, 0x114c1 & 0xFF},
	{0x114c2 & 0xFF, 0x114c3 & 0xFF},
	{0x115af & 0xFF, 0x115af & 0xFF},
	{0x115b0 & 0xFF, 0x115b1 & 0xFF},
	{0x115b2 & 0xFF, 0x115b5 & 0xFF},
	{0x115b8 & 0xFF, 0x115bb & 0xFF},
	{0x115bc & 0xFF, 0x115bd & 0xFF},
	{0x115be & 0xFF, 0x115be & 0xFF},
	{0x115bf & 0xFF, 0x115c0 & 0xFF},
	{0x115dc & 0xFF, 0x115dd & 0xFF},
	{0x11630 & 0xFF, 0x11632 & 0xFF},
	{0x11633 & 0xFF, 0x1163a & 0xFF},
	{0x1163b & 0xFF, 0x1163c & 0xFF},
	{0x1163d & 0xFF, 0x1163d & 0xFF},
	{0x1163e & 0xFF, 0x1163e & 0xFF},
	{0x1163f & 0xFF, 0x11640 & 0xFF},
	{0x116ab & 0xFF, 0x116ab & 0xFF},
	{0x116ac & 0xFF, 0x116ac & 0xFF},
	{0x116ad & 0xFF, 0x116ad & 0xFF},
	{0x116ae & 0xFF, 0x116af & 0xFF},
	{0x116b0 & 0xFF, 0x116b5 & 0xFF},
	{0x116b6 & 0xFF, 0x116b6 & 0xFF},
	{0x116b7 & 0xFF, 0x116b7 & 0xFF},
	{0x1171d & 0xFF, 0x1171f & 0xFF},
	{0x11722 & 0xFF, 0x11725 & 0xFF},
	{0x11726 & 0xFF, 0x11726 & 0xFF},
	{0x11727 & 0xFF, 0x1172b & 0xFF},
	{0x1182c & 0xFF, 0x1182e & 0xFF},
	{0x1182f & 0xFF, 0x11837 & 0xFF},
	{0x11838 & 0xFF, 0x11838 & 0xFF},
	{0x11839 & 0xFF, 0x1183a & 0xFF},
	{0x11930 & 0xFF, 0x11930 & 0xFF},
	{0x11931 & 0xFF, 0x11935 & 0xFF},
	{0x11937 & 0xFF, 0x11938 & 0xFF},
	{0x1193b & 0xFF, 0x1193c & 0xFF},
	{0x1193d & 0xFF, 0x1193d & 0xFF},
	{0x1193e & 0xFF, 0x1193e & 0xFF},
	{0x1193f & 0xFF, 0x1193f & 0xFF},
	{0x11940 & 0xFF, 0x11940 & 0xFF},
	{0x11941 & 0xFF, 0x11941 & 0xFF},
	{0x11942 & 0xFF, 0x11942 & 0xFF},
	{0x11943 & 0xFF, 0x11943 & 0xFF},
	{0x119d1 & 0xFF, 0x119d3 & 0xFF},
	{0x119d4 & 0xFF, 0x119d7 & 0xFF},
	{0x119da & 0xFF, 0x119db & 0xFF},
	{0x119dc & 0xFF, 0x119df & 0xFF},
	{0x119e0 & 0xFF, 0x119e0 & 0xFF},
	{0x119e4 & 0xFF, 0x119e4 & 0xFF},
	{0x11a01 & 0xFF, 0x11a0a & 0xFF},
	{0x11a33 & 0xFF, 0x11a38 & 0xFF},
	{0x11a39 & 0xFF, 0x11a39 & 0xFF},
	{0x11a3a & 0xFF, 0x11a3a & 0xFF},
	{0x11a3b & 0xFF, 0x11a3e & 0xFF},
	{0x11a47 & 0xFF, 0x11a47 & 0xFF},
	{0x11a51 & 0xFF, 0x11a56 & 0xFF},
	{0x11a57 & 0xFF, 0x11a58 & 0xFF},
	{0x11a59 & 0xFF, 0x11a5b & 0xFF},
	{0x11a84 & 0xFF, 0x11a89 & 0xFF},
	{0x11a8a & 0xFF, 0x11a96 & 0xFF},
	{0x11a97 & 0xFF, 0x11a97 & 0xFF},
	{0x11a98 & 0xFF, 0x11a99 & 0xFF},
	{0x11c2f & 0xFF, 0x11c2f & 0xFF},
	{0x11c30 & 0xFF, 0x11c36 & 0xFF},
	{0x11c38 & 0xFF, 0x11c3d & 0xFF},
	{0x11c3e & 0xFF, 0x11c3e & 0xFF},
	{0x11c3f & 0xFF, 0x11c3f & 0xFF},
	{0x11c92 & 0xFF, 0x11ca7 & 0xFF},
	{0x11ca9 & 0xFF, 0x11ca9 & 0xFF},
	{0x11caa & 0xFF, 0x11cb0 & 0xFF},
	{0x11cb1 & 0xFF, 0x11cb1 & 0xFF},
	{0x11cb2 & 0xFF, 0x11cb3 & 0xFF},
	{0x11cb4 & 0xFF, 0x11cb4 & 0xFF},
	{0x11cb5 & 0xFF, 0x11cb6 & 0xFF},
	{0x11d31 & 0xFF, 0x11d36 & 0xFF},
	{0x11d3a & 0xFF, 0x11d3a & 0xFF},
	{0x11d3c & 0xFF, 0x11d3d & 0xFF},
	{0x11d3f & 0xFF, 0x11d45 & 0xFF},
	{0x11d46 & 0xFF, 0x11d46 & 0xFF},
	{0x11d47 & 0xFF, 0x11d47 & 0xFF},
	{0x11d8a & 0xFF, 0x11d8e & 0xFF},
	{0x11d90 & 0xFF, 0x11d91 & 0xFF},
	{0x11d93 & 0xFF, 0x11d94 & 0xFF},
	{0x11d95 & 0xFF, 0x11d95 & 0xFF},
	{0x11d96 & 0xFF, 0x11d96 & 0xFF},
	{0x11d97 & 0xFF, 0x11d97 & 0xFF},
	{0x11ef3 & 0xFF, 0x11ef4 & 0xFF},
	{0x11ef5 & 0xFF, 0x11ef6 & 0xFF},
	{0x11f00 & 0xFF, 0x11f01 & 0xFF},
	{0x11f02 & 0xFF, 0x11f02 & 0xFF},
	{0x11f03 & 0xFF, 0x11f03 & 0xFF},
	{0x11f34 & 0xFF, 0x11f35 & 0xFF},
	{0x11f36 & 0xFF, 0x11f3a & 0xFF},
	{0x11f3e & 0xFF, 0x11f3f & 0xFF},
	{0x11f40 & 0xFF, 0x11f40 & 0xFF},
	{0x11f41 & 0xFF, 0x11f41 & 0xFF},
	{0x11f42 & 0xFF, 0x11f42 & 0xFF},
	{0x13430 & 0xFF, 0x1343f & 0xFF},
	{0x13440 & 0xFF, 0x13440 & 0xFF},
	{0x13447 & 0xFF, 0x13455 & 0xFF},
	{0x16af0 & 0xFF, 0x16af4 & 0xFF},
	{0x16b30 & 0xFF, 0x16b36 & 0xFF},
	{0x16f4f & 0xFF, 0x16f4f & 0xFF},
	{0x16f51 & 0xFF, 0x16f87 & 0xFF},
	{0x16f8f & 0xFF, 0x16f92 & 0xFF},
	{0x16fe4 & 0xFF, 0x16fe4 & 0xFF},
	{0x16ff0 & 0xFF, 0x16ff1 & 0xFF},
	{0x1bc9d & 0xFF, 0x1bc9e & 0xFF},
	{0x1bca0 & 0xFF, 0x1bca3 & 0xFF},
	{0x1cf00 & 0xFF, 0x1cf2d & 0xFF},
	{0x1cf30 & 0xFF, 0x1cf46 & 0xFF},
	{0x1d165 & 0xFF, 0x1d165 & 0xFF},
	{0x1d166 & 0xFF, 0x1d166 & 0xFF},
	{0x1d167 & 0xFF, 0x1d169 & 0xFF},
	{0x1d16d & 0xFF, 0x1d16d & 0xFF},
	{0x1d16e & 0xFF, 0x1d172 & 0xFF},
	{0x1d173 & 0xFF, 0x1d17a & 0xFF},
	{0x1d17b & 0xFF, 0x1d182 & 0xFF},
	{0x1d185 & 0xFF, 0x1d18b & 0xFF},
	{0x1d1aa & 0xFF, 0x1d1ad & 0xFF},
	{0x1d242 & 0xFF, 0x1d244 & 0xFF},
	{0x1da00 & 0xFF, 0x1da36 & 0xFF},
	{0x1da3b & 0xFF, 0x1da6c & 0xFF},
	{0x1da75 & 0xFF, 0x1da75 & 0xFF},
	{0x1da84 & 0xFF, 0x1da84 & 0xFF},
	{0x1da9b & 0xFF, 0x1da9f & 0xFF},
	{0x1daa1 & 0xFF, 0x1daaf & 0xFF},
	{0x1e000 & 0xFF, 0x1e006 & 0xFF},
	{0x1e008 & 0xFF, 0x1e018 & 0xFF},
	{0x1e01b & 0xFF, 0x1e021 & 0xFF},
	{0x1e023 & 0xFF, 0x1e024 & 0xFF},
	{0x1e026 & 0xFF, 0x1e02a & 0xFF},
	{0x1e08f & 0xFF, 0x1e08f & 0xFF},
	{0x1e130 & 0xFF, 0x1e136 & 0xFF},
	{0x1e2ae & 0xFF, 0x1e2ae & 0xFF},
	{0x1e2ec & 0xFF, 0x1e2ef & 0xFF},
	{0x1e4ec & 0xFF, 0x1e4ef & 0xFF},
	{0x1e8d0 & 0xFF, 0x1e8d6 & 0xFF},
	{0x1e944 & 0xFF, 0x1e94a & 0xFF},
	{0x1f1e6 & 0xFF, 0x1f1ff & 0xFF},
	{0x1f3fb & 0xFF, 0x1f3ff & 0xFF},
	{0xe0000 & 0xFF, 0xe001f & 0xFF},
	{0xe0020 & 0xFF, 0xe007f & 0xFF},
	{0xe0080 & 0xFF, 0xe00ff & 0xFF},
	{0xe0100 & 0xFF, 0xe01ef & 0xFF},
	{0xe01f0 & 0xFF, 0xe01ff & 0xFF},
	{0xe0200 & 0xFF, 0xe02ff & 0xFF},
	{0xe0300 & 0xFF, 0xe03ff & 0xFF},
	{0xe0400 & 0xFF, 0xe04ff & 0xFF},
	{0xe0500 & 0xFF, 0xe05ff & 0xFF},
	{0xe0600 & 0xFF, 0xe06ff & 0xFF},
	{0xe0700 & 0xFF, 0xe07ff & 0xFF},
	{0xe0800 & 0xFF, 0xe08ff & 0xFF},
	{0xe0900 & 0xFF, 0xe09ff & 0xFF},
	{0xe0a00 & 0xFF, 0xe0aff & 0xFF},
	{0xe0b00 & 0xFF, 0xe0bff & 0xFF},
	{0xe0c00 & 0xFF, 0xe0cff & 0xFF},
	{0xe0d00 & 0xFF, 0xe0dff & 0xFF},
	{0xe0e00 & 0xFF, 0xe0eff & 0xFF},
	{0xe0f00 & 0xFF, 0xe0fff & 0xFF}};

static const uint8_t unicode_classtab[]={
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_LF,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_CR,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_L,
	UNICODE_GRAPHEMEBREAK_V,
	UNICODE_GRAPHEMEBREAK_T,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_ZWJ,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_L,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_LV,
	UNICODE_GRAPHEMEBREAK_LVT,
	UNICODE_GRAPHEMEBREAK_V,
	UNICODE_GRAPHEMEBREAK_T,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Prepend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_SpacingMark,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Regional_Indicator,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Extend,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control,
	UNICODE_GRAPHEMEBREAK_Control};

static const size_t unicode_starting_indextab[]={
	0,
	3,
	4,
	5,
	6,
	7,
	8,
	9,
	10,
	11,
	12,
	13,
	14,
	15,
	16,
	17,
	19,
	23,
	24,
	25,
	26,
	27,
	28,
	29,
	32,
	44,
	45,
	48,
	166,
	168,
	169,
	170,
	171,
	172,
	173,
	174,
	175,
	176,
	177,
	178,
	179,
	180,
	181,
	182,
	183,
	184,
	185,
	186,
	187,
	188,
	189,
	190,
	191,
	192,
	193,
	194,
	195,
	196,
	197,
	198,
	199,
	200,
	201,
	202,
	203,
	204,
	205,
	206,
	207,
	208,
	209,
	210,
	211,
	212,
	213,
	214,
	215,
	251,
	254,
	255,
	257,
	258,
	259,
	266,
	269,
	270,
	271,
	272,
	273,
	274,
	275,
	276,
	277,
	278,
	279,
	280,
	281,
	282,
	284,
	285,
	286,
	287,
	308,
	362,
	363,
	367,
	444,
	463,
	465,
	466,
	474,
	480,
	481,
	482,
	484,
	488,
	489,
	497,
	499,
	3584,
	3585,
	3586,
	3587,
	3588,
	3589,
	3590,
	3591,
	3592,
	3593,
	3594,
	3595,
	3596,
	3597,
	3598,
	3599
};

static const char32_t unicode_starting_pagetab[]={
	0,
	7,
	8,
	9,
	14,
	24,
	30,
	40,
	64,
	85,
	105,
	130,
	152,
	160,
	172,
	187,
	190,
	191,
	205,
	210,
	218,
	232,
	257,
	269,
	270,
	277,
	278,
	280,
	282,
	286,
	298,
	311,
	330,
	337,
	357,
	376,
	395,
	414,
	433,
	452,
	471,
	491,
	510,
	529,
	548,
	567,
	586,
	605,
	625,
	644,
	663,
	682,
	701,
	720,
	739,
	759,
	778,
	797,
	816,
	835,
	854,
	873,
	893,
	912,
	931,
	950,
	969,
	988,
	1007,
	1027,
	1046,
	1065,
	1084,
	1103,
	1122,
	1141,
	1161,
	1174,
	1175,
	1178,
	1180,
	1181,
	1182,
	1183,
	1189,
	1190,
	1192,
	1194,
	1209,
	1224,
	1235,
	1248,
	1266,
	1274,
	1287,
	1291,
	1295,
	1312,
	1325,
	1337,
	1349,
	1351,
	1360,
	1363,
	1364,
	1365,
	1370,
	1372,
	1374,
	1383,
	1384,
	1390,
	1396,
	1397,
	1399,
	1400,
	1401,
	1402,
	1403,
	1404,
	1407,
	1409,
	1410,
	1411,
	1412,
	1413,
	1414,
	1415,
	1416,
	1417,
	1418,
	1419,
	1420,
	1421,
	1422
};

